/********************************************************************************
** Form generated from reading UI file 'astroCalcDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ASTROCALCDIALOG_H
#define UI_ASTROCALCDIALOG_H

#include <QtCharts/QChartView>
#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "AngleSpinBox.hpp"
#include "AstroCalcAlmanacWidget.hpp"
#include "Dialog.hpp"
#include "gui/ColorButton.hpp"

QT_BEGIN_NAMESPACE

class Ui_astroCalcDialogForm
{
public:
    QVBoxLayout *verticalLayout;
    TitleBar *titleBar;
    QFrame *viewContent;
    QGridLayout *gridLayout_6;
    QListWidget *stackListWidget;
    QStackedWidget *stackedWidget;
    QWidget *stackedWidgetPage1;
    QGridLayout *gridLayout_2;
    QTabWidget *tabWidgetPositions;
    QWidget *tabObjects;
    QGridLayout *gridLayout_22;
    QHBoxLayout *horizontalLayout_16;
    QLabel *celestialMagnitudeLimitLabel;
    QDoubleSpinBox *celestialMagnitudeDoubleSpinBox;
    QCheckBox *horizontalCoordinatesCheckBox;
    QSpacerItem *horizontalSpacer_2;
    QComboBox *celestialCategoryComboBox;
    QTreeWidget *celestialPositionsTreeWidget;
    QHBoxLayout *horizontalLayout_15;
    QLabel *celestialPositionsTimeLabel;
    QPushButton *celestialPositionsSaveButton;
    QPushButton *celestialPositionsUpdateButton;
    QWidget *tabSolarSystem;
    QGridLayout *gridLayout_23;
    QLabel *hecPositionsHeaderLabel;
    QHBoxLayout *horizontalLayout_23;
    QLabel *hecPositionsTimeLabel;
    QPushButton *hecPositionsSaveButton;
    QPushButton *hecPositionsExportButton;
    QPushButton *hecPositionsUpdateButton;
    QVBoxLayout *verticalLayout_4;
    QTreeWidget *hecPositionsTreeWidget;
    QCheckBox *hecSelectedMinorPlanetsCheckBox;
    QHBoxLayout *horizontalLayout_18;
    QCheckBox *hecBrightCometsCheckBox;
    QDoubleSpinBox *hecMagnitudeLimitSpinBox;
    QSpacerItem *horizontalSpacer_17;
    QChartView *hecPositionsChartView;
    QWidget *stackedWidgetPage2;
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout_11;
    QPushButton *ephemerisCleanupButton;
    QPushButton *ephemerisSaveButton;
    QPushButton *ephemerisPushButton;
    QTreeWidget *ephemerisTreeWidget;
    QHBoxLayout *horizontalLayout;
    QLabel *celestialBodyName;
    QComboBox *celestialBodyComboBox;
    QLabel *labelAnd;
    QComboBox *secondaryCelestialBodyComboBox;
    QLabel *labelOr;
    QCheckBox *allNakedEyePlanetsCheckBox;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout_17;
    QLabel *label;
    QCheckBox *ephemerisShowLineCheckBox;
    QCheckBox *ephemerisShowMarkersCheckBox;
    QCheckBox *ephemerisShowDatesCheckBox;
    QCheckBox *ephemerisShowMagnitudesCheckBox;
    QToolButton *pushButtonExtraEphemerisDialog;
    QSpacerItem *horizontalSpacer;
    QCheckBox *ephemerisIgnoreDateTestCheckBox;
    QCheckBox *ephemerisHorizontalCoordinatesCheckBox;
    QSpacerItem *horizontalSpacer_6;
    QHBoxLayout *horizontalLayout_26;
    ColorButton *genericMarkerColor;
    ColorButton *secondaryMarkerColor;
    ColorButton *selectedMarkerColor;
    ColorButton *mercuryMarkerColor;
    ColorButton *venusMarkerColor;
    ColorButton *marsMarkerColor;
    ColorButton *jupiterMarkerColor;
    ColorButton *saturnMarkerColor;
    QHBoxLayout *horizontalLayout_25;
    QHBoxLayout *horizontalLayout_3;
    QLabel *dateFromLabel;
    QSpinBox *dateFromYearSpinBox;
    QSpinBox *dateFromMonthSpinBox;
    QSpinBox *dateFromDaySpinBox;
    QSpinBox *dateFromHourSpinBox;
    QSpinBox *dateFromMinuteSpinBox;
    QToolButton *pushButtonNow;
    QHBoxLayout *horizontalLayout_4;
    QLabel *dateToLabel;
    QSpinBox *dateToDurationSpinBox;
    QComboBox *dateToUnitsComboBox;
    QSpacerItem *horizontalSpacer_8;
    QHBoxLayout *horizontalLayout_2;
    QLabel *ephemerisStepLabel;
    QComboBox *ephemerisStepComboBox;
    QToolButton *pushButtonCustomStepsDialog;
    QLabel *ephemerisNotificationLabel;
    QWidget *stackedWidgetPage3;
    QGridLayout *gridLayout_16;
    QHBoxLayout *horizontalLayout_30;
    QPushButton *rtsCleanupButton;
    QPushButton *rtsSaveButton;
    QPushButton *rtsCalculateButton;
    QTreeWidget *rtsTreeWidget;
    QHBoxLayout *horizontalLayout_31;
    QHBoxLayout *horizontalLayout_34;
    QLabel *rtsCelestialBodyLabel;
    QLabel *rtsCelestialBodyNameLabel;
    QHBoxLayout *horizontalLayout_35;
    QLabel *rtsFromLabel;
    QSpinBox *rtsFromYearSpinBox;
    QSpinBox *rtsFromMonthSpinBox;
    QHBoxLayout *horizontalLayout_32;
    QLabel *rtsToLabel;
    QSpinBox *rtsToMonthSpinBox;
    QLabel *rtsToMonthsLabel;
    QLabel *rtsHeaderLabel;
    QLabel *rtsNotificationLabel;
    QWidget *stackedWidgetPage4;
    QGridLayout *gridLayout_4;
    QHBoxLayout *horizontalLayout_5;
    QLabel *betweenObjectsLabel;
    QComboBox *object1ComboBox;
    QLabel *andLabel;
    QComboBox *object2ComboBox;
    QPushButton *selectObjectButton;
    QHBoxLayout *horizontalLayout_33;
    QHBoxLayout *horizontalLayout_8;
    QLabel *allowedSeparationLabel;
    AngleSpinBox *allowedSeparationSpinBox;
    QSpacerItem *horizontalSpacer_9;
    QHBoxLayout *horizontalLayout_6;
    QLabel *phenomenFromLabel;
    QSpinBox *phenomenFromYearSpinBox;
    QSpinBox *phenomenFromMonthSpinBox;
    QHBoxLayout *horizontalLayout_7;
    QLabel *phenomenToLabel;
    QSpinBox *phenomenToMonthSpinBox;
    QLabel *phenomenToMonthsLabel;
    QHBoxLayout *horizontalLayout_9;
    QPushButton *phenomenaCleanupButton;
    QPushButton *phenomenaSaveButton;
    QPushButton *phenomenaPushButton;
    QTreeWidget *phenomenaTreeWidget;
    QHBoxLayout *horizontalLayout_27;
    QLabel *label_5;
    QCheckBox *phenomenaOppositionCheckBox;
    QCheckBox *phenomenaPerihelionAphelionCheckBox;
    QCheckBox *phenomenaElongationQuadratureCheckBox;
    QSpacerItem *horizontalSpacer_4;
    QWidget *stackedWidgetPage5;
    QGridLayout *gridLayout_5;
    QTabWidget *tabWidgetGraphs;
    QWidget *tabAltVsTime;
    QGridLayout *gridLayout_12;
    QHBoxLayout *horizontalLayout_14;
    QCheckBox *sunAltitudeCheckBox;
    QCheckBox *moonAltitudeCheckBox;
    QCheckBox *positiveAltitudeOnlyCheckBox;
    QSpinBox *positiveAltitudeLimitSpinBox;
    QSpacerItem *horizontalSpacer_18;
    QPushButton *exportAltVsTimePushButton;
    QChartView *altVsTimeChartView;
    QWidget *tabAziVsTime;
    QGridLayout *gridLayout_14;
    QHBoxLayout *aziVsTimeHorizontalLayout;
    QSpacerItem *aziVsTimeHorizontalSpacer;
    QPushButton *exportAziVsTimePushButton;
    QChartView *aziVsTimeChartView;
    QWidget *tabMonthlyElevation;
    QGridLayout *gridLayout_15;
    QChartView *monthlyElevationChartView;
    QHBoxLayout *horizontalLayout_10;
    QCheckBox *monthlyElevationPositiveCheckBox;
    QSpinBox *monthlyElevationPositiveLimitSpinBox;
    QSlider *monthlyElevationTime;
    QLabel *monthlyElevationTimeInfo;
    QSpacerItem *horizontalSpacer_19;
    QPushButton *exportMonthlyElevationPushButton;
    QWidget *tabTwoGraphs;
    QGridLayout *gridLayout_7;
    QGridLayout *gridLayout_17;
    QComboBox *graphsFirstComboBox;
    QHBoxLayout *horizontalLayout_29;
    QLabel *graphsDurationLabel;
    QSpinBox *graphsDurationSpinBox;
    QLabel *graphsMonthsLabel;
    QSpacerItem *horizontalSpacer_20;
    QLabel *graphsStepLabel;
    QSpinBox *graphsHourStepsSpinBox;
    QSpacerItem *horizontalSpacer_5;
    QLabel *graphsSecondLabel;
    QComboBox *graphsSecondComboBox;
    QLabel *graphsFirstLabel;
    QLabel *graphsNoteLabel;
    QHBoxLayout *drawGraphHorizontalLayout;
    QPushButton *drawGraphsPushButton;
    QPushButton *exportGraphsPushButton;
    QHBoxLayout *horizontalLayout_13;
    QSpacerItem *horizontalSpacer_11;
    QComboBox *graphsCelestialBodyComboBox;
    QSpacerItem *horizontalSpacer_12;
    QChartView *twoGraphsChartView;
    QWidget *tabLunarElongation;
    QGridLayout *gridLayout_13;
    QChartView *lunarElongationChartView;
    QGridLayout *gridLayout_25;
    QLabel *lunarElongationLimitLabel;
    QLabel *lunarElongationNote;
    QSpinBox *lunarElongationLimitSpinBox;
    QSpacerItem *horizontalSpacer_16;
    QPushButton *exportLunarElongationPushButton;
    QWidget *stackedWidgetPage6;
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout_3;
    QLabel *label_3;
    QListWidget *wutCategoryListWidget;
    QVBoxLayout *verticalLayout_5;
    QGridLayout *gridLayout_26;
    QLabel *label_6;
    AngleSpinBox *wutAngularSizeLimitMinSpinBox;
    AngleSpinBox *wutAngularSizeLimitMaxSpinBox;
    AngleSpinBox *wutAltitudeMinSpinBox;
    QCheckBox *wutAngularSizeLimitCheckBox;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_12;
    QLabel *wutTimeIntervalLabel;
    QComboBox *wutComboBox;
    QSpacerItem *horizontalSpacer_10;
    QLabel *label_2;
    QDoubleSpinBox *wutMagnitudeDoubleSpinBox;
    QLineEdit *wutMatchingObjectsLineEdit;
    QTreeWidget *wutMatchingObjectsTreeWidget;
    QPushButton *saveObjectsButton;
    QWidget *stackedWidgetPage7;
    QGridLayout *gridLayout_8;
    QGridLayout *gridLayoutPCalc;
    QComboBox *secondCelestialBodyComboBox;
    QComboBox *firstCelestialBodyComboBox;
    QLabel *labelFCB;
    QLabel *labelSCB;
    QTabWidget *tabWidgetPC;
    QWidget *tabData;
    QGridLayout *gridLayout_10;
    QGridLayout *gridLayout_9;
    QLabel *labelMeanMotionSCBValue;
    QLabel *labelSynodicPeriod;
    QLabel *labelAngularDistanceValue;
    QLabel *labelEquatorialRadiiRatioValue;
    QLabel *labelOrbitalVelocityFCB;
    QLabel *labelAngularDistance;
    QLabel *labelMeanMotionFCBValue;
    QLabel *labelMeanMotionSCB;
    QLabel *labelMeanMotionFCB;
    QLabel *labelLinearDistanceValue;
    QLabel *labelOrbitalVelocityFCBValue;
    QLabel *labelOrbitalVelocitySCB;
    QLabel *labelSynodicPeriodValue;
    QLabel *labelOrbitalPeriodsRatioValue;
    QLabel *labelOrbitalPeriodsRatio;
    QLabel *labelEquatorialRadiiRatioRatio;
    QLabel *labelLinearDistance;
    QLabel *labelOrbitalVelocitySCBValue;
    QSpacerItem *verticalSpacer;
    QWidget *tabDistanceGraph;
    QGridLayout *gridLayout_11;
    QChartView *pcChartView;
    QHBoxLayout *lunarElongationGraphHorizontalLayout;
    QSpacerItem *horizontalSpacer_15;
    QPushButton *exportPCPushButton;
    QWidget *stackedWidgetPage8;
    QGridLayout *gridLayout_18;
    QTabWidget *tabWidgetEclipses;
    QWidget *tabGolbalSolarEclipse;
    QGridLayout *gridLayout_20;
    QHBoxLayout *horizontalLayout_40;
    QPushButton *solareclipsesCleanupButton;
    QPushButton *solareclipsesSaveButton;
    QPushButton *solareclipsescontactsSaveButton;
    QPushButton *solareclipsesMapSaveButton;
    QPushButton *solareclipsesCalculateButton;
    QLabel *gammaNoteSolarEclipseLabel;
    QTreeWidget *solareclipseTreeWidget;
    QTreeWidget *solareclipsecontactsTreeWidget;
    QWidget *tabSolarEclipseLocal;
    QGridLayout *gridLayout_21;
    QHBoxLayout *horizontalLayout_44;
    QPushButton *solareclipseslocalCleanupButton;
    QPushButton *solareclipseslocalSaveButton;
    QPushButton *solareclipseslocalMapSaveButton;
    QPushButton *solareclipseslocalCalculateButton;
    QTreeWidget *solareclipselocalTreeWidget;
    QLabel *UncertaintiesNoteLabel;
    QWidget *tabLunarEclipse;
    QGridLayout *gridLayout_19;
    QTreeWidget *lunareclipseTreeWidget;
    QLabel *gammaNoteLabel;
    QHBoxLayout *horizontalLayout_39;
    QPushButton *lunareclipsesCleanupButton;
    QPushButton *lunareclipsesSaveButton;
    QPushButton *lunareclipsescontactsSaveButton;
    QPushButton *lunareclipsesCalculateButton;
    QTreeWidget *lunareclipsecontactsTreeWidget;
    QWidget *tabTransit;
    QGridLayout *gridLayout_24;
    QTreeWidget *transitTreeWidget;
    QLabel *transitNoteLabel;
    QHBoxLayout *horizontalLayout_45;
    QPushButton *transitsCleanupButton;
    QPushButton *transitsSaveButton;
    QPushButton *transitsCalculateButton;
    QGridLayout *gridLayout_28;
    QHBoxLayout *horizontalLayout_42;
    QLabel *eclipseYearsLabel;
    QSpinBox *eclipseYearsSpinBox;
    QLabel *eclipseYearsFinalLabel;
    QHBoxLayout *horizontalLayout_41;
    QLabel *eclipseHeaderLabel;
    QSpacerItem *horizontalSpacer_14;
    QLabel *eclipseFromLabel;
    QSpinBox *eclipseFromYearSpinBox;
    QWidget *eclipseFilterWidget;
    QHBoxLayout *horizontalLayout_19;
    QSpacerItem *eclipseFilterSpacer;
    QCheckBox *eclipseFilterPenumbral;
    QCheckBox *eclipseFilterHybrid;
    QCheckBox *eclipseFilterAnnular;
    QCheckBox *eclipseFilterPartial;
    QCheckBox *eclipseFilterTotal;
    QWidget *stackedWidgetPage9;
    QGridLayout *gridLayout_27;
    AstroCalcAlmanacWidget *astroCalcAlmanac;

    void setupUi(QWidget *astroCalcDialogForm)
    {
        if (astroCalcDialogForm->objectName().isEmpty())
            astroCalcDialogForm->setObjectName("astroCalcDialogForm");
        astroCalcDialogForm->resize(1030, 590);
        verticalLayout = new QVBoxLayout(astroCalcDialogForm);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        titleBar = new TitleBar(astroCalcDialogForm);
        titleBar->setObjectName("titleBar");

        verticalLayout->addWidget(titleBar);

        viewContent = new QFrame(astroCalcDialogForm);
        viewContent->setObjectName("viewContent");
        viewContent->setFrameShape(QFrame::StyledPanel);
        viewContent->setFrameShadow(QFrame::Plain);
        gridLayout_6 = new QGridLayout(viewContent);
        gridLayout_6->setSpacing(0);
        gridLayout_6->setObjectName("gridLayout_6");
        gridLayout_6->setContentsMargins(0, 0, 0, 0);
        stackListWidget = new QListWidget(viewContent);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/graphicGui/tabPlanetPos.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon.addFile(QString::fromUtf8(":/graphicGui/tabPlanetPos-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem->setIcon(icon);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/graphicGui/tabEphemeris.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon1.addFile(QString::fromUtf8(":/graphicGui/tabEphemeris-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem1 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem1->setIcon(icon1);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/graphicGui/tabTransit.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon2.addFile(QString::fromUtf8(":/graphicGui/tabTransit-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem2 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem2->setIcon(icon2);
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/graphicGui/tabPhenomena.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon3.addFile(QString::fromUtf8(":/graphicGui/tabPhenomena-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem3 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem3->setIcon(icon3);
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/graphicGui/tabGraphs.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon4.addFile(QString::fromUtf8(":/graphicGui/tabGraphs-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem4 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem4->setIcon(icon4);
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/graphicGui/tabWhatsUp.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon5.addFile(QString::fromUtf8(":/graphicGui/tabWhatsUp-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem5 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem5->setIcon(icon5);
        QIcon icon6;
        icon6.addFile(QString::fromUtf8(":/graphicGui/tabPC.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon6.addFile(QString::fromUtf8(":/graphicGui/tabPC-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem6 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem6->setIcon(icon6);
        QIcon icon7;
        icon7.addFile(QString::fromUtf8(":/graphicGui/tabEclipses.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon7.addFile(QString::fromUtf8(":/graphicGui/tabEclipses-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem7 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem7->setIcon(icon7);
        QIcon icon8;
        icon8.addFile(QString::fromUtf8(":/graphicGui/tabSSO.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon8.addFile(QString::fromUtf8(":/graphicGui/tabSSO-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem8 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem8->setIcon(icon8);
        stackListWidget->setObjectName("stackListWidget");
        stackListWidget->setFocusPolicy(Qt::NoFocus);
        stackListWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        stackListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        stackListWidget->setMovement(QListView::Static);
        stackListWidget->setFlow(QListView::LeftToRight);
        stackListWidget->setProperty("isWrapping", QVariant(false));
        stackListWidget->setResizeMode(QListView::Adjust);
        stackListWidget->setViewMode(QListView::IconMode);
        stackListWidget->setSelectionRectVisible(false);

        gridLayout_6->addWidget(stackListWidget, 0, 0, 1, 1);

        stackedWidget = new QStackedWidget(viewContent);
        stackedWidget->setObjectName("stackedWidget");
        stackedWidgetPage1 = new QWidget();
        stackedWidgetPage1->setObjectName("stackedWidgetPage1");
        gridLayout_2 = new QGridLayout(stackedWidgetPage1);
        gridLayout_2->setObjectName("gridLayout_2");
        tabWidgetPositions = new QTabWidget(stackedWidgetPage1);
        tabWidgetPositions->setObjectName("tabWidgetPositions");
        tabWidgetPositions->setTabPosition(QTabWidget::South);
        tabObjects = new QWidget();
        tabObjects->setObjectName("tabObjects");
        gridLayout_22 = new QGridLayout(tabObjects);
        gridLayout_22->setObjectName("gridLayout_22");
        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        celestialMagnitudeLimitLabel = new QLabel(tabObjects);
        celestialMagnitudeLimitLabel->setObjectName("celestialMagnitudeLimitLabel");

        horizontalLayout_16->addWidget(celestialMagnitudeLimitLabel);

        celestialMagnitudeDoubleSpinBox = new QDoubleSpinBox(tabObjects);
        celestialMagnitudeDoubleSpinBox->setObjectName("celestialMagnitudeDoubleSpinBox");
        celestialMagnitudeDoubleSpinBox->setMaximum(25.000000000000000);
        celestialMagnitudeDoubleSpinBox->setValue(12.000000000000000);

        horizontalLayout_16->addWidget(celestialMagnitudeDoubleSpinBox);

        horizontalCoordinatesCheckBox = new QCheckBox(tabObjects);
        horizontalCoordinatesCheckBox->setObjectName("horizontalCoordinatesCheckBox");

        horizontalLayout_16->addWidget(horizontalCoordinatesCheckBox);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_16->addItem(horizontalSpacer_2);

        celestialCategoryComboBox = new QComboBox(tabObjects);
        celestialCategoryComboBox->setObjectName("celestialCategoryComboBox");
        celestialCategoryComboBox->setEditable(true);
        celestialCategoryComboBox->setInsertPolicy(QComboBox::NoInsert);

        horizontalLayout_16->addWidget(celestialCategoryComboBox);


        gridLayout_22->addLayout(horizontalLayout_16, 0, 0, 1, 1);

        celestialPositionsTreeWidget = new QTreeWidget(tabObjects);
        celestialPositionsTreeWidget->setObjectName("celestialPositionsTreeWidget");
        celestialPositionsTreeWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        celestialPositionsTreeWidget->setRootIsDecorated(false);
        celestialPositionsTreeWidget->setUniformRowHeights(true);
        celestialPositionsTreeWidget->setItemsExpandable(false);
        celestialPositionsTreeWidget->setSortingEnabled(true);
        celestialPositionsTreeWidget->setExpandsOnDoubleClick(false);
        celestialPositionsTreeWidget->setColumnCount(0);
        celestialPositionsTreeWidget->header()->setProperty("showSortIndicator", QVariant(true));

        gridLayout_22->addWidget(celestialPositionsTreeWidget, 1, 0, 1, 1);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        celestialPositionsTimeLabel = new QLabel(tabObjects);
        celestialPositionsTimeLabel->setObjectName("celestialPositionsTimeLabel");

        horizontalLayout_15->addWidget(celestialPositionsTimeLabel);

        celestialPositionsSaveButton = new QPushButton(tabObjects);
        celestialPositionsSaveButton->setObjectName("celestialPositionsSaveButton");

        horizontalLayout_15->addWidget(celestialPositionsSaveButton);

        celestialPositionsUpdateButton = new QPushButton(tabObjects);
        celestialPositionsUpdateButton->setObjectName("celestialPositionsUpdateButton");

        horizontalLayout_15->addWidget(celestialPositionsUpdateButton);


        gridLayout_22->addLayout(horizontalLayout_15, 2, 0, 1, 1);

        tabWidgetPositions->addTab(tabObjects, QString());
        tabSolarSystem = new QWidget();
        tabSolarSystem->setObjectName("tabSolarSystem");
        gridLayout_23 = new QGridLayout(tabSolarSystem);
        gridLayout_23->setObjectName("gridLayout_23");
        hecPositionsHeaderLabel = new QLabel(tabSolarSystem);
        hecPositionsHeaderLabel->setObjectName("hecPositionsHeaderLabel");
        QFont font;
        font.setBold(true);
        hecPositionsHeaderLabel->setFont(font);
        hecPositionsHeaderLabel->setAlignment(Qt::AlignCenter);

        gridLayout_23->addWidget(hecPositionsHeaderLabel, 0, 0, 1, 2);

        horizontalLayout_23 = new QHBoxLayout();
        horizontalLayout_23->setObjectName("horizontalLayout_23");
        hecPositionsTimeLabel = new QLabel(tabSolarSystem);
        hecPositionsTimeLabel->setObjectName("hecPositionsTimeLabel");

        horizontalLayout_23->addWidget(hecPositionsTimeLabel);

        hecPositionsSaveButton = new QPushButton(tabSolarSystem);
        hecPositionsSaveButton->setObjectName("hecPositionsSaveButton");

        horizontalLayout_23->addWidget(hecPositionsSaveButton);

        hecPositionsExportButton = new QPushButton(tabSolarSystem);
        hecPositionsExportButton->setObjectName("hecPositionsExportButton");

        horizontalLayout_23->addWidget(hecPositionsExportButton);

        hecPositionsUpdateButton = new QPushButton(tabSolarSystem);
        hecPositionsUpdateButton->setObjectName("hecPositionsUpdateButton");

        horizontalLayout_23->addWidget(hecPositionsUpdateButton);


        gridLayout_23->addLayout(horizontalLayout_23, 4, 0, 1, 2);

        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        hecPositionsTreeWidget = new QTreeWidget(tabSolarSystem);
        hecPositionsTreeWidget->setObjectName("hecPositionsTreeWidget");
        hecPositionsTreeWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        hecPositionsTreeWidget->setRootIsDecorated(false);
        hecPositionsTreeWidget->setUniformRowHeights(true);
        hecPositionsTreeWidget->setItemsExpandable(false);
        hecPositionsTreeWidget->setSortingEnabled(true);
        hecPositionsTreeWidget->setExpandsOnDoubleClick(false);
        hecPositionsTreeWidget->setColumnCount(0);

        verticalLayout_4->addWidget(hecPositionsTreeWidget);

        hecSelectedMinorPlanetsCheckBox = new QCheckBox(tabSolarSystem);
        hecSelectedMinorPlanetsCheckBox->setObjectName("hecSelectedMinorPlanetsCheckBox");

        verticalLayout_4->addWidget(hecSelectedMinorPlanetsCheckBox);

        horizontalLayout_18 = new QHBoxLayout();
        horizontalLayout_18->setObjectName("horizontalLayout_18");
        hecBrightCometsCheckBox = new QCheckBox(tabSolarSystem);
        hecBrightCometsCheckBox->setObjectName("hecBrightCometsCheckBox");

        horizontalLayout_18->addWidget(hecBrightCometsCheckBox);

        hecMagnitudeLimitSpinBox = new QDoubleSpinBox(tabSolarSystem);
        hecMagnitudeLimitSpinBox->setObjectName("hecMagnitudeLimitSpinBox");
        hecMagnitudeLimitSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        hecMagnitudeLimitSpinBox->setMaximum(15.000000000000000);
        hecMagnitudeLimitSpinBox->setValue(9.000000000000000);

        horizontalLayout_18->addWidget(hecMagnitudeLimitSpinBox);

        horizontalSpacer_17 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_18->addItem(horizontalSpacer_17);


        verticalLayout_4->addLayout(horizontalLayout_18);


        gridLayout_23->addLayout(verticalLayout_4, 1, 0, 1, 1);

        hecPositionsChartView = new QChartView(tabSolarSystem);
        hecPositionsChartView->setObjectName("hecPositionsChartView");
        hecPositionsChartView->setRenderHints(QPainter::Antialiasing|QPainter::TextAntialiasing);

        gridLayout_23->addWidget(hecPositionsChartView, 1, 1, 1, 1);

        tabWidgetPositions->addTab(tabSolarSystem, QString());

        gridLayout_2->addWidget(tabWidgetPositions, 1, 0, 1, 1);

        stackedWidget->addWidget(stackedWidgetPage1);
        stackedWidgetPage2 = new QWidget();
        stackedWidgetPage2->setObjectName("stackedWidgetPage2");
        gridLayout_3 = new QGridLayout(stackedWidgetPage2);
        gridLayout_3->setObjectName("gridLayout_3");
        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        ephemerisCleanupButton = new QPushButton(stackedWidgetPage2);
        ephemerisCleanupButton->setObjectName("ephemerisCleanupButton");

        horizontalLayout_11->addWidget(ephemerisCleanupButton);

        ephemerisSaveButton = new QPushButton(stackedWidgetPage2);
        ephemerisSaveButton->setObjectName("ephemerisSaveButton");

        horizontalLayout_11->addWidget(ephemerisSaveButton);

        ephemerisPushButton = new QPushButton(stackedWidgetPage2);
        ephemerisPushButton->setObjectName("ephemerisPushButton");

        horizontalLayout_11->addWidget(ephemerisPushButton);


        gridLayout_3->addLayout(horizontalLayout_11, 9, 0, 1, 2);

        ephemerisTreeWidget = new QTreeWidget(stackedWidgetPage2);
        ephemerisTreeWidget->setObjectName("ephemerisTreeWidget");
        ephemerisTreeWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        ephemerisTreeWidget->setRootIsDecorated(false);
        ephemerisTreeWidget->setUniformRowHeights(true);
        ephemerisTreeWidget->setItemsExpandable(false);
        ephemerisTreeWidget->setSortingEnabled(true);
        ephemerisTreeWidget->setExpandsOnDoubleClick(false);
        ephemerisTreeWidget->setColumnCount(0);

        gridLayout_3->addWidget(ephemerisTreeWidget, 7, 0, 1, 2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        celestialBodyName = new QLabel(stackedWidgetPage2);
        celestialBodyName->setObjectName("celestialBodyName");

        horizontalLayout->addWidget(celestialBodyName);

        celestialBodyComboBox = new QComboBox(stackedWidgetPage2);
        celestialBodyComboBox->setObjectName("celestialBodyComboBox");
        celestialBodyComboBox->setEditable(true);
        celestialBodyComboBox->setInsertPolicy(QComboBox::NoInsert);

        horizontalLayout->addWidget(celestialBodyComboBox);

        labelAnd = new QLabel(stackedWidgetPage2);
        labelAnd->setObjectName("labelAnd");

        horizontalLayout->addWidget(labelAnd);

        secondaryCelestialBodyComboBox = new QComboBox(stackedWidgetPage2);
        secondaryCelestialBodyComboBox->setObjectName("secondaryCelestialBodyComboBox");
        secondaryCelestialBodyComboBox->setEditable(true);
        secondaryCelestialBodyComboBox->setInsertPolicy(QComboBox::NoInsert);

        horizontalLayout->addWidget(secondaryCelestialBodyComboBox);

        labelOr = new QLabel(stackedWidgetPage2);
        labelOr->setObjectName("labelOr");

        horizontalLayout->addWidget(labelOr);

        allNakedEyePlanetsCheckBox = new QCheckBox(stackedWidgetPage2);
        allNakedEyePlanetsCheckBox->setObjectName("allNakedEyePlanetsCheckBox");

        horizontalLayout->addWidget(allNakedEyePlanetsCheckBox);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);


        gridLayout_3->addLayout(horizontalLayout, 0, 0, 1, 2);

        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        horizontalLayout_17->setContentsMargins(-1, 0, -1, -1);
        label = new QLabel(stackedWidgetPage2);
        label->setObjectName("label");

        horizontalLayout_17->addWidget(label);

        ephemerisShowLineCheckBox = new QCheckBox(stackedWidgetPage2);
        ephemerisShowLineCheckBox->setObjectName("ephemerisShowLineCheckBox");

        horizontalLayout_17->addWidget(ephemerisShowLineCheckBox);

        ephemerisShowMarkersCheckBox = new QCheckBox(stackedWidgetPage2);
        ephemerisShowMarkersCheckBox->setObjectName("ephemerisShowMarkersCheckBox");

        horizontalLayout_17->addWidget(ephemerisShowMarkersCheckBox);

        ephemerisShowDatesCheckBox = new QCheckBox(stackedWidgetPage2);
        ephemerisShowDatesCheckBox->setObjectName("ephemerisShowDatesCheckBox");

        horizontalLayout_17->addWidget(ephemerisShowDatesCheckBox);

        ephemerisShowMagnitudesCheckBox = new QCheckBox(stackedWidgetPage2);
        ephemerisShowMagnitudesCheckBox->setObjectName("ephemerisShowMagnitudesCheckBox");

        horizontalLayout_17->addWidget(ephemerisShowMagnitudesCheckBox);

        pushButtonExtraEphemerisDialog = new QToolButton(stackedWidgetPage2);
        pushButtonExtraEphemerisDialog->setObjectName("pushButtonExtraEphemerisDialog");
        pushButtonExtraEphemerisDialog->setText(QString::fromUtf8(""));
        QIcon icon9;
        icon9.addFile(QString::fromUtf8(":/graphicGui/uibtSettings.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon9.addFile(QString::fromUtf8(":/graphicGui/uibtSettings-disabled.png"), QSize(), QIcon::Mode::Disabled, QIcon::State::Off);
        pushButtonExtraEphemerisDialog->setIcon(icon9);

        horizontalLayout_17->addWidget(pushButtonExtraEphemerisDialog);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer);

        ephemerisIgnoreDateTestCheckBox = new QCheckBox(stackedWidgetPage2);
        ephemerisIgnoreDateTestCheckBox->setObjectName("ephemerisIgnoreDateTestCheckBox");

        horizontalLayout_17->addWidget(ephemerisIgnoreDateTestCheckBox);

        ephemerisHorizontalCoordinatesCheckBox = new QCheckBox(stackedWidgetPage2);
        ephemerisHorizontalCoordinatesCheckBox->setObjectName("ephemerisHorizontalCoordinatesCheckBox");

        horizontalLayout_17->addWidget(ephemerisHorizontalCoordinatesCheckBox);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_6);

        horizontalLayout_26 = new QHBoxLayout();
        horizontalLayout_26->setObjectName("horizontalLayout_26");
        horizontalLayout_26->setContentsMargins(8, -1, 8, -1);
        genericMarkerColor = new ColorButton(stackedWidgetPage2);
        genericMarkerColor->setObjectName("genericMarkerColor");
        genericMarkerColor->setText(QString::fromUtf8(""));

        horizontalLayout_26->addWidget(genericMarkerColor);

        secondaryMarkerColor = new ColorButton(stackedWidgetPage2);
        secondaryMarkerColor->setObjectName("secondaryMarkerColor");
        secondaryMarkerColor->setText(QString::fromUtf8(""));

        horizontalLayout_26->addWidget(secondaryMarkerColor);

        selectedMarkerColor = new ColorButton(stackedWidgetPage2);
        selectedMarkerColor->setObjectName("selectedMarkerColor");
        selectedMarkerColor->setText(QString::fromUtf8(""));

        horizontalLayout_26->addWidget(selectedMarkerColor);


        horizontalLayout_17->addLayout(horizontalLayout_26);

        mercuryMarkerColor = new ColorButton(stackedWidgetPage2);
        mercuryMarkerColor->setObjectName("mercuryMarkerColor");
        mercuryMarkerColor->setText(QString::fromUtf8(""));

        horizontalLayout_17->addWidget(mercuryMarkerColor);

        venusMarkerColor = new ColorButton(stackedWidgetPage2);
        venusMarkerColor->setObjectName("venusMarkerColor");

        horizontalLayout_17->addWidget(venusMarkerColor);

        marsMarkerColor = new ColorButton(stackedWidgetPage2);
        marsMarkerColor->setObjectName("marsMarkerColor");
        marsMarkerColor->setText(QString::fromUtf8(""));

        horizontalLayout_17->addWidget(marsMarkerColor);

        jupiterMarkerColor = new ColorButton(stackedWidgetPage2);
        jupiterMarkerColor->setObjectName("jupiterMarkerColor");
        jupiterMarkerColor->setText(QString::fromUtf8(""));

        horizontalLayout_17->addWidget(jupiterMarkerColor);

        saturnMarkerColor = new ColorButton(stackedWidgetPage2);
        saturnMarkerColor->setObjectName("saturnMarkerColor");
        saturnMarkerColor->setText(QString::fromUtf8(""));

        horizontalLayout_17->addWidget(saturnMarkerColor);


        gridLayout_3->addLayout(horizontalLayout_17, 3, 0, 1, 2);

        horizontalLayout_25 = new QHBoxLayout();
        horizontalLayout_25->setObjectName("horizontalLayout_25");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        dateFromLabel = new QLabel(stackedWidgetPage2);
        dateFromLabel->setObjectName("dateFromLabel");

        horizontalLayout_3->addWidget(dateFromLabel);

        dateFromYearSpinBox = new QSpinBox(stackedWidgetPage2);
        dateFromYearSpinBox->setObjectName("dateFromYearSpinBox");
        dateFromYearSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        dateFromYearSpinBox->setMinimum(-13000);
        dateFromYearSpinBox->setMaximum(17000);

        horizontalLayout_3->addWidget(dateFromYearSpinBox);

        dateFromMonthSpinBox = new QSpinBox(stackedWidgetPage2);
        dateFromMonthSpinBox->setObjectName("dateFromMonthSpinBox");
        dateFromMonthSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        dateFromMonthSpinBox->setMinimum(1);
        dateFromMonthSpinBox->setMaximum(12);

        horizontalLayout_3->addWidget(dateFromMonthSpinBox);

        dateFromDaySpinBox = new QSpinBox(stackedWidgetPage2);
        dateFromDaySpinBox->setObjectName("dateFromDaySpinBox");
        dateFromDaySpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        dateFromDaySpinBox->setMinimum(1);
        dateFromDaySpinBox->setMaximum(31);

        horizontalLayout_3->addWidget(dateFromDaySpinBox);

        dateFromHourSpinBox = new QSpinBox(stackedWidgetPage2);
        dateFromHourSpinBox->setObjectName("dateFromHourSpinBox");
        dateFromHourSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        dateFromHourSpinBox->setMinimum(0);
        dateFromHourSpinBox->setMaximum(23);

        horizontalLayout_3->addWidget(dateFromHourSpinBox);

        dateFromMinuteSpinBox = new QSpinBox(stackedWidgetPage2);
        dateFromMinuteSpinBox->setObjectName("dateFromMinuteSpinBox");
        dateFromMinuteSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        dateFromMinuteSpinBox->setMaximum(59);

        horizontalLayout_3->addWidget(dateFromMinuteSpinBox);

        pushButtonNow = new QToolButton(stackedWidgetPage2);
        pushButtonNow->setObjectName("pushButtonNow");
        QIcon icon10;
        icon10.addFile(QString::fromUtf8(":/graphicGui/btTimeNow-off.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon10.addFile(QString::fromUtf8(":/graphicGui/btTimeNow-off.png"), QSize(), QIcon::Mode::Disabled, QIcon::State::Off);
        pushButtonNow->setIcon(icon10);

        horizontalLayout_3->addWidget(pushButtonNow);


        horizontalLayout_25->addLayout(horizontalLayout_3);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        dateToLabel = new QLabel(stackedWidgetPage2);
        dateToLabel->setObjectName("dateToLabel");

        horizontalLayout_4->addWidget(dateToLabel);

        dateToDurationSpinBox = new QSpinBox(stackedWidgetPage2);
        dateToDurationSpinBox->setObjectName("dateToDurationSpinBox");
        dateToDurationSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        dateToDurationSpinBox->setMinimum(1);
        dateToDurationSpinBox->setMaximum(1000);

        horizontalLayout_4->addWidget(dateToDurationSpinBox);

        dateToUnitsComboBox = new QComboBox(stackedWidgetPage2);
        dateToUnitsComboBox->setObjectName("dateToUnitsComboBox");

        horizontalLayout_4->addWidget(dateToUnitsComboBox);


        horizontalLayout_25->addLayout(horizontalLayout_4);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_25->addItem(horizontalSpacer_8);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        ephemerisStepLabel = new QLabel(stackedWidgetPage2);
        ephemerisStepLabel->setObjectName("ephemerisStepLabel");

        horizontalLayout_2->addWidget(ephemerisStepLabel);

        ephemerisStepComboBox = new QComboBox(stackedWidgetPage2);
        ephemerisStepComboBox->setObjectName("ephemerisStepComboBox");
        ephemerisStepComboBox->setEditable(true);
        ephemerisStepComboBox->setInsertPolicy(QComboBox::NoInsert);

        horizontalLayout_2->addWidget(ephemerisStepComboBox);

        pushButtonCustomStepsDialog = new QToolButton(stackedWidgetPage2);
        pushButtonCustomStepsDialog->setObjectName("pushButtonCustomStepsDialog");
        QIcon icon11;
        icon11.addFile(QString::fromUtf8(":/graphicGui/uibtTime.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon11.addFile(QString::fromUtf8(":/graphicGui/uibtTime-disabled.png"), QSize(), QIcon::Mode::Disabled, QIcon::State::Off);
        pushButtonCustomStepsDialog->setIcon(icon11);

        horizontalLayout_2->addWidget(pushButtonCustomStepsDialog);


        horizontalLayout_25->addLayout(horizontalLayout_2);


        gridLayout_3->addLayout(horizontalLayout_25, 2, 0, 1, 2);

        ephemerisNotificationLabel = new QLabel(stackedWidgetPage2);
        ephemerisNotificationLabel->setObjectName("ephemerisNotificationLabel");
        ephemerisNotificationLabel->setWordWrap(true);

        gridLayout_3->addWidget(ephemerisNotificationLabel, 8, 0, 1, 2);

        stackedWidget->addWidget(stackedWidgetPage2);
        stackedWidgetPage3 = new QWidget();
        stackedWidgetPage3->setObjectName("stackedWidgetPage3");
        gridLayout_16 = new QGridLayout(stackedWidgetPage3);
        gridLayout_16->setObjectName("gridLayout_16");
        horizontalLayout_30 = new QHBoxLayout();
        horizontalLayout_30->setObjectName("horizontalLayout_30");
        rtsCleanupButton = new QPushButton(stackedWidgetPage3);
        rtsCleanupButton->setObjectName("rtsCleanupButton");

        horizontalLayout_30->addWidget(rtsCleanupButton);

        rtsSaveButton = new QPushButton(stackedWidgetPage3);
        rtsSaveButton->setObjectName("rtsSaveButton");

        horizontalLayout_30->addWidget(rtsSaveButton);

        rtsCalculateButton = new QPushButton(stackedWidgetPage3);
        rtsCalculateButton->setObjectName("rtsCalculateButton");

        horizontalLayout_30->addWidget(rtsCalculateButton);


        gridLayout_16->addLayout(horizontalLayout_30, 4, 0, 1, 1);

        rtsTreeWidget = new QTreeWidget(stackedWidgetPage3);
        rtsTreeWidget->setObjectName("rtsTreeWidget");
        rtsTreeWidget->setRootIsDecorated(false);
        rtsTreeWidget->setUniformRowHeights(true);
        rtsTreeWidget->setItemsExpandable(false);
        rtsTreeWidget->setSortingEnabled(true);
        rtsTreeWidget->setExpandsOnDoubleClick(false);
        rtsTreeWidget->setColumnCount(0);
        rtsTreeWidget->header()->setProperty("showSortIndicator", QVariant(true));

        gridLayout_16->addWidget(rtsTreeWidget, 2, 0, 1, 1);

        horizontalLayout_31 = new QHBoxLayout();
        horizontalLayout_31->setObjectName("horizontalLayout_31");
        horizontalLayout_34 = new QHBoxLayout();
        horizontalLayout_34->setObjectName("horizontalLayout_34");
        rtsCelestialBodyLabel = new QLabel(stackedWidgetPage3);
        rtsCelestialBodyLabel->setObjectName("rtsCelestialBodyLabel");

        horizontalLayout_34->addWidget(rtsCelestialBodyLabel);

        rtsCelestialBodyNameLabel = new QLabel(stackedWidgetPage3);
        rtsCelestialBodyNameLabel->setObjectName("rtsCelestialBodyNameLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(rtsCelestialBodyNameLabel->sizePolicy().hasHeightForWidth());
        rtsCelestialBodyNameLabel->setSizePolicy(sizePolicy);
        rtsCelestialBodyNameLabel->setFont(font);

        horizontalLayout_34->addWidget(rtsCelestialBodyNameLabel);


        horizontalLayout_31->addLayout(horizontalLayout_34);

        horizontalLayout_35 = new QHBoxLayout();
        horizontalLayout_35->setObjectName("horizontalLayout_35");
        rtsFromLabel = new QLabel(stackedWidgetPage3);
        rtsFromLabel->setObjectName("rtsFromLabel");

        horizontalLayout_35->addWidget(rtsFromLabel);

        rtsFromYearSpinBox = new QSpinBox(stackedWidgetPage3);
        rtsFromYearSpinBox->setObjectName("rtsFromYearSpinBox");
        rtsFromYearSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        rtsFromYearSpinBox->setMinimum(-13000);
        rtsFromYearSpinBox->setMaximum(17000);

        horizontalLayout_35->addWidget(rtsFromYearSpinBox);

        rtsFromMonthSpinBox = new QSpinBox(stackedWidgetPage3);
        rtsFromMonthSpinBox->setObjectName("rtsFromMonthSpinBox");
        rtsFromMonthSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        rtsFromMonthSpinBox->setMinimum(1);
        rtsFromMonthSpinBox->setMaximum(12);

        horizontalLayout_35->addWidget(rtsFromMonthSpinBox);


        horizontalLayout_31->addLayout(horizontalLayout_35);

        horizontalLayout_32 = new QHBoxLayout();
        horizontalLayout_32->setObjectName("horizontalLayout_32");
        rtsToLabel = new QLabel(stackedWidgetPage3);
        rtsToLabel->setObjectName("rtsToLabel");

        horizontalLayout_32->addWidget(rtsToLabel);

        rtsToMonthSpinBox = new QSpinBox(stackedWidgetPage3);
        rtsToMonthSpinBox->setObjectName("rtsToMonthSpinBox");
        rtsToMonthSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        rtsToMonthSpinBox->setMinimum(1);
        rtsToMonthSpinBox->setMaximum(60);

        horizontalLayout_32->addWidget(rtsToMonthSpinBox);

        rtsToMonthsLabel = new QLabel(stackedWidgetPage3);
        rtsToMonthsLabel->setObjectName("rtsToMonthsLabel");

        horizontalLayout_32->addWidget(rtsToMonthsLabel);


        horizontalLayout_31->addLayout(horizontalLayout_32);


        gridLayout_16->addLayout(horizontalLayout_31, 1, 0, 1, 1);

        rtsHeaderLabel = new QLabel(stackedWidgetPage3);
        rtsHeaderLabel->setObjectName("rtsHeaderLabel");
        rtsHeaderLabel->setFont(font);
        rtsHeaderLabel->setAlignment(Qt::AlignCenter);
        rtsHeaderLabel->setWordWrap(true);

        gridLayout_16->addWidget(rtsHeaderLabel, 0, 0, 1, 1);

        rtsNotificationLabel = new QLabel(stackedWidgetPage3);
        rtsNotificationLabel->setObjectName("rtsNotificationLabel");
        rtsNotificationLabel->setAlignment(Qt::AlignCenter);
        rtsNotificationLabel->setWordWrap(true);

        gridLayout_16->addWidget(rtsNotificationLabel, 3, 0, 1, 1);

        stackedWidget->addWidget(stackedWidgetPage3);
        stackedWidgetPage4 = new QWidget();
        stackedWidgetPage4->setObjectName("stackedWidgetPage4");
        gridLayout_4 = new QGridLayout(stackedWidgetPage4);
        gridLayout_4->setObjectName("gridLayout_4");
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        betweenObjectsLabel = new QLabel(stackedWidgetPage4);
        betweenObjectsLabel->setObjectName("betweenObjectsLabel");

        horizontalLayout_5->addWidget(betweenObjectsLabel);

        object1ComboBox = new QComboBox(stackedWidgetPage4);
        object1ComboBox->setObjectName("object1ComboBox");
        object1ComboBox->setEditable(true);
        object1ComboBox->setInsertPolicy(QComboBox::NoInsert);

        horizontalLayout_5->addWidget(object1ComboBox);

        andLabel = new QLabel(stackedWidgetPage4);
        andLabel->setObjectName("andLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(andLabel->sizePolicy().hasHeightForWidth());
        andLabel->setSizePolicy(sizePolicy1);
        andLabel->setAlignment(Qt::AlignCenter);

        horizontalLayout_5->addWidget(andLabel);

        object2ComboBox = new QComboBox(stackedWidgetPage4);
        object2ComboBox->setObjectName("object2ComboBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(object2ComboBox->sizePolicy().hasHeightForWidth());
        object2ComboBox->setSizePolicy(sizePolicy2);
        object2ComboBox->setEditable(true);
        object2ComboBox->setInsertPolicy(QComboBox::NoInsert);

        horizontalLayout_5->addWidget(object2ComboBox);

        selectObjectButton = new QPushButton(stackedWidgetPage4);
        selectObjectButton->setObjectName("selectObjectButton");
        selectObjectButton->setText(QString::fromUtf8(""));

        horizontalLayout_5->addWidget(selectObjectButton);


        gridLayout_4->addLayout(horizontalLayout_5, 0, 0, 1, 2);

        horizontalLayout_33 = new QHBoxLayout();
        horizontalLayout_33->setObjectName("horizontalLayout_33");
        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        allowedSeparationLabel = new QLabel(stackedWidgetPage4);
        allowedSeparationLabel->setObjectName("allowedSeparationLabel");

        horizontalLayout_8->addWidget(allowedSeparationLabel);

        allowedSeparationSpinBox = new AngleSpinBox(stackedWidgetPage4);
        allowedSeparationSpinBox->setObjectName("allowedSeparationSpinBox");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(allowedSeparationSpinBox->sizePolicy().hasHeightForWidth());
        allowedSeparationSpinBox->setSizePolicy(sizePolicy3);
        allowedSeparationSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_8->addWidget(allowedSeparationSpinBox);


        horizontalLayout_33->addLayout(horizontalLayout_8);

        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_33->addItem(horizontalSpacer_9);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        phenomenFromLabel = new QLabel(stackedWidgetPage4);
        phenomenFromLabel->setObjectName("phenomenFromLabel");

        horizontalLayout_6->addWidget(phenomenFromLabel);

        phenomenFromYearSpinBox = new QSpinBox(stackedWidgetPage4);
        phenomenFromYearSpinBox->setObjectName("phenomenFromYearSpinBox");
        phenomenFromYearSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        phenomenFromYearSpinBox->setMinimum(-13000);
        phenomenFromYearSpinBox->setMaximum(17000);

        horizontalLayout_6->addWidget(phenomenFromYearSpinBox);

        phenomenFromMonthSpinBox = new QSpinBox(stackedWidgetPage4);
        phenomenFromMonthSpinBox->setObjectName("phenomenFromMonthSpinBox");
        phenomenFromMonthSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        phenomenFromMonthSpinBox->setMinimum(1);
        phenomenFromMonthSpinBox->setMaximum(12);

        horizontalLayout_6->addWidget(phenomenFromMonthSpinBox);


        horizontalLayout_33->addLayout(horizontalLayout_6);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        horizontalLayout_7->setContentsMargins(-1, -1, 0, -1);
        phenomenToLabel = new QLabel(stackedWidgetPage4);
        phenomenToLabel->setObjectName("phenomenToLabel");

        horizontalLayout_7->addWidget(phenomenToLabel);

        phenomenToMonthSpinBox = new QSpinBox(stackedWidgetPage4);
        phenomenToMonthSpinBox->setObjectName("phenomenToMonthSpinBox");
        phenomenToMonthSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        phenomenToMonthSpinBox->setMinimum(1);
        phenomenToMonthSpinBox->setMaximum(60);

        horizontalLayout_7->addWidget(phenomenToMonthSpinBox);

        phenomenToMonthsLabel = new QLabel(stackedWidgetPage4);
        phenomenToMonthsLabel->setObjectName("phenomenToMonthsLabel");

        horizontalLayout_7->addWidget(phenomenToMonthsLabel);


        horizontalLayout_33->addLayout(horizontalLayout_7);


        gridLayout_4->addLayout(horizontalLayout_33, 1, 0, 1, 2);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        phenomenaCleanupButton = new QPushButton(stackedWidgetPage4);
        phenomenaCleanupButton->setObjectName("phenomenaCleanupButton");

        horizontalLayout_9->addWidget(phenomenaCleanupButton);

        phenomenaSaveButton = new QPushButton(stackedWidgetPage4);
        phenomenaSaveButton->setObjectName("phenomenaSaveButton");

        horizontalLayout_9->addWidget(phenomenaSaveButton);

        phenomenaPushButton = new QPushButton(stackedWidgetPage4);
        phenomenaPushButton->setObjectName("phenomenaPushButton");

        horizontalLayout_9->addWidget(phenomenaPushButton);


        gridLayout_4->addLayout(horizontalLayout_9, 6, 0, 1, 2);

        phenomenaTreeWidget = new QTreeWidget(stackedWidgetPage4);
        phenomenaTreeWidget->setObjectName("phenomenaTreeWidget");
        phenomenaTreeWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        phenomenaTreeWidget->setRootIsDecorated(false);
        phenomenaTreeWidget->setUniformRowHeights(true);
        phenomenaTreeWidget->setItemsExpandable(false);
        phenomenaTreeWidget->setSortingEnabled(true);
        phenomenaTreeWidget->setExpandsOnDoubleClick(false);
        phenomenaTreeWidget->setColumnCount(0);

        gridLayout_4->addWidget(phenomenaTreeWidget, 5, 0, 1, 2);

        horizontalLayout_27 = new QHBoxLayout();
        horizontalLayout_27->setObjectName("horizontalLayout_27");
        label_5 = new QLabel(stackedWidgetPage4);
        label_5->setObjectName("label_5");

        horizontalLayout_27->addWidget(label_5);

        phenomenaOppositionCheckBox = new QCheckBox(stackedWidgetPage4);
        phenomenaOppositionCheckBox->setObjectName("phenomenaOppositionCheckBox");

        horizontalLayout_27->addWidget(phenomenaOppositionCheckBox);

        phenomenaPerihelionAphelionCheckBox = new QCheckBox(stackedWidgetPage4);
        phenomenaPerihelionAphelionCheckBox->setObjectName("phenomenaPerihelionAphelionCheckBox");

        horizontalLayout_27->addWidget(phenomenaPerihelionAphelionCheckBox);

        phenomenaElongationQuadratureCheckBox = new QCheckBox(stackedWidgetPage4);
        phenomenaElongationQuadratureCheckBox->setObjectName("phenomenaElongationQuadratureCheckBox");

        horizontalLayout_27->addWidget(phenomenaElongationQuadratureCheckBox);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_27->addItem(horizontalSpacer_4);


        gridLayout_4->addLayout(horizontalLayout_27, 3, 0, 1, 2);

        stackedWidget->addWidget(stackedWidgetPage4);
        stackedWidgetPage5 = new QWidget();
        stackedWidgetPage5->setObjectName("stackedWidgetPage5");
        gridLayout_5 = new QGridLayout(stackedWidgetPage5);
        gridLayout_5->setObjectName("gridLayout_5");
        tabWidgetGraphs = new QTabWidget(stackedWidgetPage5);
        tabWidgetGraphs->setObjectName("tabWidgetGraphs");
        QFont font1;
        font1.setBold(false);
        tabWidgetGraphs->setFont(font1);
        tabWidgetGraphs->setTabPosition(QTabWidget::South);
        tabAltVsTime = new QWidget();
        tabAltVsTime->setObjectName("tabAltVsTime");
        gridLayout_12 = new QGridLayout(tabAltVsTime);
        gridLayout_12->setObjectName("gridLayout_12");
        gridLayout_12->setContentsMargins(0, 0, 0, 4);
        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        sunAltitudeCheckBox = new QCheckBox(tabAltVsTime);
        sunAltitudeCheckBox->setObjectName("sunAltitudeCheckBox");

        horizontalLayout_14->addWidget(sunAltitudeCheckBox);

        moonAltitudeCheckBox = new QCheckBox(tabAltVsTime);
        moonAltitudeCheckBox->setObjectName("moonAltitudeCheckBox");

        horizontalLayout_14->addWidget(moonAltitudeCheckBox);

        positiveAltitudeOnlyCheckBox = new QCheckBox(tabAltVsTime);
        positiveAltitudeOnlyCheckBox->setObjectName("positiveAltitudeOnlyCheckBox");

        horizontalLayout_14->addWidget(positiveAltitudeOnlyCheckBox);

        positiveAltitudeLimitSpinBox = new QSpinBox(tabAltVsTime);
        positiveAltitudeLimitSpinBox->setObjectName("positiveAltitudeLimitSpinBox");
        positiveAltitudeLimitSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        positiveAltitudeLimitSpinBox->setMinimum(-85);
        positiveAltitudeLimitSpinBox->setMaximum(85);

        horizontalLayout_14->addWidget(positiveAltitudeLimitSpinBox);

        horizontalSpacer_18 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_18);

        exportAltVsTimePushButton = new QPushButton(tabAltVsTime);
        exportAltVsTimePushButton->setObjectName("exportAltVsTimePushButton");

        horizontalLayout_14->addWidget(exportAltVsTimePushButton);


        gridLayout_12->addLayout(horizontalLayout_14, 1, 0, 1, 1);

        altVsTimeChartView = new QChartView(tabAltVsTime);
        altVsTimeChartView->setObjectName("altVsTimeChartView");
        altVsTimeChartView->setFocusPolicy(Qt::NoFocus);
        altVsTimeChartView->setAcceptDrops(false);

        gridLayout_12->addWidget(altVsTimeChartView, 0, 0, 1, 2);

        tabWidgetGraphs->addTab(tabAltVsTime, QString());
        tabAziVsTime = new QWidget();
        tabAziVsTime->setObjectName("tabAziVsTime");
        gridLayout_14 = new QGridLayout(tabAziVsTime);
        gridLayout_14->setObjectName("gridLayout_14");
        gridLayout_14->setContentsMargins(0, 0, 0, 4);
        aziVsTimeHorizontalLayout = new QHBoxLayout();
        aziVsTimeHorizontalLayout->setObjectName("aziVsTimeHorizontalLayout");
        aziVsTimeHorizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        aziVsTimeHorizontalLayout->addItem(aziVsTimeHorizontalSpacer);

        exportAziVsTimePushButton = new QPushButton(tabAziVsTime);
        exportAziVsTimePushButton->setObjectName("exportAziVsTimePushButton");

        aziVsTimeHorizontalLayout->addWidget(exportAziVsTimePushButton);


        gridLayout_14->addLayout(aziVsTimeHorizontalLayout, 1, 0, 1, 1);

        aziVsTimeChartView = new QChartView(tabAziVsTime);
        aziVsTimeChartView->setObjectName("aziVsTimeChartView");

        gridLayout_14->addWidget(aziVsTimeChartView, 0, 0, 1, 1);

        tabWidgetGraphs->addTab(tabAziVsTime, QString());
        tabMonthlyElevation = new QWidget();
        tabMonthlyElevation->setObjectName("tabMonthlyElevation");
        gridLayout_15 = new QGridLayout(tabMonthlyElevation);
        gridLayout_15->setObjectName("gridLayout_15");
        gridLayout_15->setContentsMargins(0, 0, 0, 4);
        monthlyElevationChartView = new QChartView(tabMonthlyElevation);
        monthlyElevationChartView->setObjectName("monthlyElevationChartView");

        gridLayout_15->addWidget(monthlyElevationChartView, 0, 0, 1, 2);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        monthlyElevationPositiveCheckBox = new QCheckBox(tabMonthlyElevation);
        monthlyElevationPositiveCheckBox->setObjectName("monthlyElevationPositiveCheckBox");

        horizontalLayout_10->addWidget(monthlyElevationPositiveCheckBox);

        monthlyElevationPositiveLimitSpinBox = new QSpinBox(tabMonthlyElevation);
        monthlyElevationPositiveLimitSpinBox->setObjectName("monthlyElevationPositiveLimitSpinBox");
        monthlyElevationPositiveLimitSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        monthlyElevationPositiveLimitSpinBox->setMaximum(85);

        horizontalLayout_10->addWidget(monthlyElevationPositiveLimitSpinBox);

        monthlyElevationTime = new QSlider(tabMonthlyElevation);
        monthlyElevationTime->setObjectName("monthlyElevationTime");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(monthlyElevationTime->sizePolicy().hasHeightForWidth());
        monthlyElevationTime->setSizePolicy(sizePolicy4);
        monthlyElevationTime->setMaximum(23);
        monthlyElevationTime->setPageStep(1);
        monthlyElevationTime->setOrientation(Qt::Horizontal);

        horizontalLayout_10->addWidget(monthlyElevationTime);

        monthlyElevationTimeInfo = new QLabel(tabMonthlyElevation);
        monthlyElevationTimeInfo->setObjectName("monthlyElevationTimeInfo");
        monthlyElevationTimeInfo->setAlignment(Qt::AlignCenter);

        horizontalLayout_10->addWidget(monthlyElevationTimeInfo);

        horizontalSpacer_19 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_10->addItem(horizontalSpacer_19);

        exportMonthlyElevationPushButton = new QPushButton(tabMonthlyElevation);
        exportMonthlyElevationPushButton->setObjectName("exportMonthlyElevationPushButton");

        horizontalLayout_10->addWidget(exportMonthlyElevationPushButton);


        gridLayout_15->addLayout(horizontalLayout_10, 1, 0, 1, 1);

        tabWidgetGraphs->addTab(tabMonthlyElevation, QString());
        tabTwoGraphs = new QWidget();
        tabTwoGraphs->setObjectName("tabTwoGraphs");
        gridLayout_7 = new QGridLayout(tabTwoGraphs);
        gridLayout_7->setObjectName("gridLayout_7");
        gridLayout_7->setContentsMargins(0, 0, 0, 4);
        gridLayout_17 = new QGridLayout();
        gridLayout_17->setObjectName("gridLayout_17");
        graphsFirstComboBox = new QComboBox(tabTwoGraphs);
        graphsFirstComboBox->setObjectName("graphsFirstComboBox");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(graphsFirstComboBox->sizePolicy().hasHeightForWidth());
        graphsFirstComboBox->setSizePolicy(sizePolicy5);
        graphsFirstComboBox->setEditable(true);
        graphsFirstComboBox->setInsertPolicy(QComboBox::NoInsert);
        graphsFirstComboBox->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_17->addWidget(graphsFirstComboBox, 1, 1, 1, 1);

        horizontalLayout_29 = new QHBoxLayout();
        horizontalLayout_29->setObjectName("horizontalLayout_29");
        graphsDurationLabel = new QLabel(tabTwoGraphs);
        graphsDurationLabel->setObjectName("graphsDurationLabel");

        horizontalLayout_29->addWidget(graphsDurationLabel);

        graphsDurationSpinBox = new QSpinBox(tabTwoGraphs);
        graphsDurationSpinBox->setObjectName("graphsDurationSpinBox");
        graphsDurationSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        graphsDurationSpinBox->setMinimum(1);
        graphsDurationSpinBox->setMaximum(600);
        graphsDurationSpinBox->setValue(12);

        horizontalLayout_29->addWidget(graphsDurationSpinBox);

        graphsMonthsLabel = new QLabel(tabTwoGraphs);
        graphsMonthsLabel->setObjectName("graphsMonthsLabel");

        horizontalLayout_29->addWidget(graphsMonthsLabel);

        horizontalSpacer_20 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_29->addItem(horizontalSpacer_20);

        graphsStepLabel = new QLabel(tabTwoGraphs);
        graphsStepLabel->setObjectName("graphsStepLabel");

        horizontalLayout_29->addWidget(graphsStepLabel);

        graphsHourStepsSpinBox = new QSpinBox(tabTwoGraphs);
        graphsHourStepsSpinBox->setObjectName("graphsHourStepsSpinBox");
        graphsHourStepsSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        graphsHourStepsSpinBox->setMinimum(1);
        graphsHourStepsSpinBox->setMaximum(240);
        graphsHourStepsSpinBox->setValue(24);

        horizontalLayout_29->addWidget(graphsHourStepsSpinBox);

        horizontalSpacer_5 = new QSpacerItem(20, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_29->addItem(horizontalSpacer_5);


        gridLayout_17->addLayout(horizontalLayout_29, 1, 2, 1, 1);

        graphsSecondLabel = new QLabel(tabTwoGraphs);
        graphsSecondLabel->setObjectName("graphsSecondLabel");
        graphsSecondLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_17->addWidget(graphsSecondLabel, 2, 0, 1, 1);

        graphsSecondComboBox = new QComboBox(tabTwoGraphs);
        graphsSecondComboBox->setObjectName("graphsSecondComboBox");
        sizePolicy5.setHeightForWidth(graphsSecondComboBox->sizePolicy().hasHeightForWidth());
        graphsSecondComboBox->setSizePolicy(sizePolicy5);
        graphsSecondComboBox->setEditable(true);
        graphsSecondComboBox->setInsertPolicy(QComboBox::NoInsert);
        graphsSecondComboBox->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_17->addWidget(graphsSecondComboBox, 2, 1, 1, 1);

        graphsFirstLabel = new QLabel(tabTwoGraphs);
        graphsFirstLabel->setObjectName("graphsFirstLabel");
        graphsFirstLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_17->addWidget(graphsFirstLabel, 1, 0, 1, 1);

        graphsNoteLabel = new QLabel(tabTwoGraphs);
        graphsNoteLabel->setObjectName("graphsNoteLabel");
        graphsNoteLabel->setAlignment(Qt::AlignCenter);
        graphsNoteLabel->setWordWrap(true);

        gridLayout_17->addWidget(graphsNoteLabel, 0, 0, 1, 3);

        drawGraphHorizontalLayout = new QHBoxLayout();
        drawGraphHorizontalLayout->setObjectName("drawGraphHorizontalLayout");
        drawGraphsPushButton = new QPushButton(tabTwoGraphs);
        drawGraphsPushButton->setObjectName("drawGraphsPushButton");
        sizePolicy5.setHeightForWidth(drawGraphsPushButton->sizePolicy().hasHeightForWidth());
        drawGraphsPushButton->setSizePolicy(sizePolicy5);

        drawGraphHorizontalLayout->addWidget(drawGraphsPushButton);

        exportGraphsPushButton = new QPushButton(tabTwoGraphs);
        exportGraphsPushButton->setObjectName("exportGraphsPushButton");

        drawGraphHorizontalLayout->addWidget(exportGraphsPushButton);


        gridLayout_17->addLayout(drawGraphHorizontalLayout, 2, 2, 1, 1);


        gridLayout_7->addLayout(gridLayout_17, 2, 0, 1, 2);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setSpacing(0);
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer_11);

        graphsCelestialBodyComboBox = new QComboBox(tabTwoGraphs);
        graphsCelestialBodyComboBox->setObjectName("graphsCelestialBodyComboBox");
        sizePolicy5.setHeightForWidth(graphsCelestialBodyComboBox->sizePolicy().hasHeightForWidth());
        graphsCelestialBodyComboBox->setSizePolicy(sizePolicy5);
        graphsCelestialBodyComboBox->setEditable(true);
        graphsCelestialBodyComboBox->setInsertPolicy(QComboBox::NoInsert);

        horizontalLayout_13->addWidget(graphsCelestialBodyComboBox);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer_12);


        gridLayout_7->addLayout(horizontalLayout_13, 0, 0, 1, 2);

        twoGraphsChartView = new QChartView(tabTwoGraphs);
        twoGraphsChartView->setObjectName("twoGraphsChartView");

        gridLayout_7->addWidget(twoGraphsChartView, 1, 0, 1, 2);

        tabWidgetGraphs->addTab(tabTwoGraphs, QString());
        tabLunarElongation = new QWidget();
        tabLunarElongation->setObjectName("tabLunarElongation");
        gridLayout_13 = new QGridLayout(tabLunarElongation);
        gridLayout_13->setObjectName("gridLayout_13");
        gridLayout_13->setContentsMargins(0, 0, 0, 4);
        lunarElongationChartView = new QChartView(tabLunarElongation);
        lunarElongationChartView->setObjectName("lunarElongationChartView");

        gridLayout_13->addWidget(lunarElongationChartView, 0, 0, 1, 2);

        gridLayout_25 = new QGridLayout();
        gridLayout_25->setObjectName("gridLayout_25");
        lunarElongationLimitLabel = new QLabel(tabLunarElongation);
        lunarElongationLimitLabel->setObjectName("lunarElongationLimitLabel");

        gridLayout_25->addWidget(lunarElongationLimitLabel, 1, 0, 1, 1);

        lunarElongationNote = new QLabel(tabLunarElongation);
        lunarElongationNote->setObjectName("lunarElongationNote");
        sizePolicy.setHeightForWidth(lunarElongationNote->sizePolicy().hasHeightForWidth());
        lunarElongationNote->setSizePolicy(sizePolicy);
        lunarElongationNote->setAlignment(Qt::AlignCenter);

        gridLayout_25->addWidget(lunarElongationNote, 0, 0, 1, 4);

        lunarElongationLimitSpinBox = new QSpinBox(tabLunarElongation);
        lunarElongationLimitSpinBox->setObjectName("lunarElongationLimitSpinBox");
        lunarElongationLimitSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        lunarElongationLimitSpinBox->setMaximum(180);

        gridLayout_25->addWidget(lunarElongationLimitSpinBox, 1, 1, 1, 1);

        horizontalSpacer_16 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_25->addItem(horizontalSpacer_16, 1, 2, 1, 1);

        exportLunarElongationPushButton = new QPushButton(tabLunarElongation);
        exportLunarElongationPushButton->setObjectName("exportLunarElongationPushButton");

        gridLayout_25->addWidget(exportLunarElongationPushButton, 1, 3, 1, 1);


        gridLayout_13->addLayout(gridLayout_25, 2, 0, 1, 1);

        tabWidgetGraphs->addTab(tabLunarElongation, QString());

        gridLayout_5->addWidget(tabWidgetGraphs, 2, 0, 1, 1);

        stackedWidget->addWidget(stackedWidgetPage5);
        stackedWidgetPage6 = new QWidget();
        stackedWidgetPage6->setObjectName("stackedWidgetPage6");
        gridLayout = new QGridLayout(stackedWidgetPage6);
        gridLayout->setObjectName("gridLayout");
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        label_3 = new QLabel(stackedWidgetPage6);
        label_3->setObjectName("label_3");

        verticalLayout_3->addWidget(label_3);

        wutCategoryListWidget = new QListWidget(stackedWidgetPage6);
        wutCategoryListWidget->setObjectName("wutCategoryListWidget");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(wutCategoryListWidget->sizePolicy().hasHeightForWidth());
        wutCategoryListWidget->setSizePolicy(sizePolicy6);

        verticalLayout_3->addWidget(wutCategoryListWidget);


        gridLayout->addLayout(verticalLayout_3, 0, 0, 2, 1);

        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setObjectName("verticalLayout_5");
        gridLayout_26 = new QGridLayout();
        gridLayout_26->setObjectName("gridLayout_26");
        label_6 = new QLabel(stackedWidgetPage6);
        label_6->setObjectName("label_6");
        QSizePolicy sizePolicy7(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(label_6->sizePolicy().hasHeightForWidth());
        label_6->setSizePolicy(sizePolicy7);

        gridLayout_26->addWidget(label_6, 2, 0, 1, 1);

        wutAngularSizeLimitMinSpinBox = new AngleSpinBox(stackedWidgetPage6);
        wutAngularSizeLimitMinSpinBox->setObjectName("wutAngularSizeLimitMinSpinBox");
        wutAngularSizeLimitMinSpinBox->setEnabled(true);
        wutAngularSizeLimitMinSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_26->addWidget(wutAngularSizeLimitMinSpinBox, 1, 1, 1, 1);

        wutAngularSizeLimitMaxSpinBox = new AngleSpinBox(stackedWidgetPage6);
        wutAngularSizeLimitMaxSpinBox->setObjectName("wutAngularSizeLimitMaxSpinBox");
        wutAngularSizeLimitMaxSpinBox->setEnabled(true);
        wutAngularSizeLimitMaxSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_26->addWidget(wutAngularSizeLimitMaxSpinBox, 1, 2, 1, 1);

        wutAltitudeMinSpinBox = new AngleSpinBox(stackedWidgetPage6);
        wutAltitudeMinSpinBox->setObjectName("wutAltitudeMinSpinBox");
        wutAltitudeMinSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_26->addWidget(wutAltitudeMinSpinBox, 2, 2, 1, 1);

        wutAngularSizeLimitCheckBox = new QCheckBox(stackedWidgetPage6);
        wutAngularSizeLimitCheckBox->setObjectName("wutAngularSizeLimitCheckBox");
        sizePolicy2.setHeightForWidth(wutAngularSizeLimitCheckBox->sizePolicy().hasHeightForWidth());
        wutAngularSizeLimitCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_26->addWidget(wutAngularSizeLimitCheckBox, 1, 0, 1, 1);

        label_4 = new QLabel(stackedWidgetPage6);
        label_4->setObjectName("label_4");

        gridLayout_26->addWidget(label_4, 3, 0, 1, 1);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        wutTimeIntervalLabel = new QLabel(stackedWidgetPage6);
        wutTimeIntervalLabel->setObjectName("wutTimeIntervalLabel");

        horizontalLayout_12->addWidget(wutTimeIntervalLabel);

        wutComboBox = new QComboBox(stackedWidgetPage6);
        wutComboBox->setObjectName("wutComboBox");

        horizontalLayout_12->addWidget(wutComboBox);

        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_10);

        label_2 = new QLabel(stackedWidgetPage6);
        label_2->setObjectName("label_2");

        horizontalLayout_12->addWidget(label_2);

        wutMagnitudeDoubleSpinBox = new QDoubleSpinBox(stackedWidgetPage6);
        wutMagnitudeDoubleSpinBox->setObjectName("wutMagnitudeDoubleSpinBox");
        wutMagnitudeDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        wutMagnitudeDoubleSpinBox->setMinimum(-21.000000000000000);
        wutMagnitudeDoubleSpinBox->setMaximum(21.000000000000000);
        wutMagnitudeDoubleSpinBox->setValue(10.000000000000000);

        horizontalLayout_12->addWidget(wutMagnitudeDoubleSpinBox);


        gridLayout_26->addLayout(horizontalLayout_12, 0, 0, 1, 3);


        verticalLayout_5->addLayout(gridLayout_26);

        wutMatchingObjectsLineEdit = new QLineEdit(stackedWidgetPage6);
        wutMatchingObjectsLineEdit->setObjectName("wutMatchingObjectsLineEdit");

        verticalLayout_5->addWidget(wutMatchingObjectsLineEdit);

        wutMatchingObjectsTreeWidget = new QTreeWidget(stackedWidgetPage6);
        wutMatchingObjectsTreeWidget->setObjectName("wutMatchingObjectsTreeWidget");
        wutMatchingObjectsTreeWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        wutMatchingObjectsTreeWidget->setRootIsDecorated(false);
        wutMatchingObjectsTreeWidget->setUniformRowHeights(true);
        wutMatchingObjectsTreeWidget->setItemsExpandable(false);
        wutMatchingObjectsTreeWidget->setSortingEnabled(true);
        wutMatchingObjectsTreeWidget->setColumnCount(0);

        verticalLayout_5->addWidget(wutMatchingObjectsTreeWidget);

        saveObjectsButton = new QPushButton(stackedWidgetPage6);
        saveObjectsButton->setObjectName("saveObjectsButton");

        verticalLayout_5->addWidget(saveObjectsButton);


        gridLayout->addLayout(verticalLayout_5, 1, 1, 1, 1);

        stackedWidget->addWidget(stackedWidgetPage6);
        stackedWidgetPage7 = new QWidget();
        stackedWidgetPage7->setObjectName("stackedWidgetPage7");
        gridLayout_8 = new QGridLayout(stackedWidgetPage7);
        gridLayout_8->setObjectName("gridLayout_8");
        gridLayoutPCalc = new QGridLayout();
        gridLayoutPCalc->setObjectName("gridLayoutPCalc");
        secondCelestialBodyComboBox = new QComboBox(stackedWidgetPage7);
        secondCelestialBodyComboBox->setObjectName("secondCelestialBodyComboBox");
        secondCelestialBodyComboBox->setEditable(true);
        secondCelestialBodyComboBox->setInsertPolicy(QComboBox::NoInsert);

        gridLayoutPCalc->addWidget(secondCelestialBodyComboBox, 1, 1, 1, 1);

        firstCelestialBodyComboBox = new QComboBox(stackedWidgetPage7);
        firstCelestialBodyComboBox->setObjectName("firstCelestialBodyComboBox");
        firstCelestialBodyComboBox->setEditable(true);
        firstCelestialBodyComboBox->setInsertPolicy(QComboBox::NoInsert);

        gridLayoutPCalc->addWidget(firstCelestialBodyComboBox, 1, 0, 1, 1);

        labelFCB = new QLabel(stackedWidgetPage7);
        labelFCB->setObjectName("labelFCB");

        gridLayoutPCalc->addWidget(labelFCB, 0, 0, 1, 1);

        labelSCB = new QLabel(stackedWidgetPage7);
        labelSCB->setObjectName("labelSCB");

        gridLayoutPCalc->addWidget(labelSCB, 0, 1, 1, 1);


        gridLayout_8->addLayout(gridLayoutPCalc, 0, 0, 1, 1);

        tabWidgetPC = new QTabWidget(stackedWidgetPage7);
        tabWidgetPC->setObjectName("tabWidgetPC");
        tabWidgetPC->setTabPosition(QTabWidget::South);
        tabData = new QWidget();
        tabData->setObjectName("tabData");
        gridLayout_10 = new QGridLayout(tabData);
        gridLayout_10->setObjectName("gridLayout_10");
        gridLayout_10->setContentsMargins(0, 0, 0, 0);
        gridLayout_9 = new QGridLayout();
        gridLayout_9->setObjectName("gridLayout_9");
        labelMeanMotionSCBValue = new QLabel(tabData);
        labelMeanMotionSCBValue->setObjectName("labelMeanMotionSCBValue");

        gridLayout_9->addWidget(labelMeanMotionSCBValue, 7, 1, 1, 1);

        labelSynodicPeriod = new QLabel(tabData);
        labelSynodicPeriod->setObjectName("labelSynodicPeriod");
        labelSynodicPeriod->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_9->addWidget(labelSynodicPeriod, 2, 0, 1, 1);

        labelAngularDistanceValue = new QLabel(tabData);
        labelAngularDistanceValue->setObjectName("labelAngularDistanceValue");

        gridLayout_9->addWidget(labelAngularDistanceValue, 1, 1, 1, 1);

        labelEquatorialRadiiRatioValue = new QLabel(tabData);
        labelEquatorialRadiiRatioValue->setObjectName("labelEquatorialRadiiRatioValue");

        gridLayout_9->addWidget(labelEquatorialRadiiRatioValue, 8, 1, 1, 1);

        labelOrbitalVelocityFCB = new QLabel(tabData);
        labelOrbitalVelocityFCB->setObjectName("labelOrbitalVelocityFCB");
        labelOrbitalVelocityFCB->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_9->addWidget(labelOrbitalVelocityFCB, 4, 0, 1, 1);

        labelAngularDistance = new QLabel(tabData);
        labelAngularDistance->setObjectName("labelAngularDistance");
        labelAngularDistance->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_9->addWidget(labelAngularDistance, 1, 0, 1, 1);

        labelMeanMotionFCBValue = new QLabel(tabData);
        labelMeanMotionFCBValue->setObjectName("labelMeanMotionFCBValue");

        gridLayout_9->addWidget(labelMeanMotionFCBValue, 5, 1, 1, 1);

        labelMeanMotionSCB = new QLabel(tabData);
        labelMeanMotionSCB->setObjectName("labelMeanMotionSCB");
        labelMeanMotionSCB->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_9->addWidget(labelMeanMotionSCB, 7, 0, 1, 1);

        labelMeanMotionFCB = new QLabel(tabData);
        labelMeanMotionFCB->setObjectName("labelMeanMotionFCB");
        labelMeanMotionFCB->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_9->addWidget(labelMeanMotionFCB, 5, 0, 1, 1);

        labelLinearDistanceValue = new QLabel(tabData);
        labelLinearDistanceValue->setObjectName("labelLinearDistanceValue");

        gridLayout_9->addWidget(labelLinearDistanceValue, 0, 1, 1, 1);

        labelOrbitalVelocityFCBValue = new QLabel(tabData);
        labelOrbitalVelocityFCBValue->setObjectName("labelOrbitalVelocityFCBValue");

        gridLayout_9->addWidget(labelOrbitalVelocityFCBValue, 4, 1, 1, 1);

        labelOrbitalVelocitySCB = new QLabel(tabData);
        labelOrbitalVelocitySCB->setObjectName("labelOrbitalVelocitySCB");
        labelOrbitalVelocitySCB->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_9->addWidget(labelOrbitalVelocitySCB, 6, 0, 1, 1);

        labelSynodicPeriodValue = new QLabel(tabData);
        labelSynodicPeriodValue->setObjectName("labelSynodicPeriodValue");

        gridLayout_9->addWidget(labelSynodicPeriodValue, 2, 1, 1, 1);

        labelOrbitalPeriodsRatioValue = new QLabel(tabData);
        labelOrbitalPeriodsRatioValue->setObjectName("labelOrbitalPeriodsRatioValue");

        gridLayout_9->addWidget(labelOrbitalPeriodsRatioValue, 3, 1, 1, 1);

        labelOrbitalPeriodsRatio = new QLabel(tabData);
        labelOrbitalPeriodsRatio->setObjectName("labelOrbitalPeriodsRatio");
        labelOrbitalPeriodsRatio->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_9->addWidget(labelOrbitalPeriodsRatio, 3, 0, 1, 1);

        labelEquatorialRadiiRatioRatio = new QLabel(tabData);
        labelEquatorialRadiiRatioRatio->setObjectName("labelEquatorialRadiiRatioRatio");
        labelEquatorialRadiiRatioRatio->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_9->addWidget(labelEquatorialRadiiRatioRatio, 8, 0, 1, 1);

        labelLinearDistance = new QLabel(tabData);
        labelLinearDistance->setObjectName("labelLinearDistance");
        labelLinearDistance->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_9->addWidget(labelLinearDistance, 0, 0, 1, 1);

        labelOrbitalVelocitySCBValue = new QLabel(tabData);
        labelOrbitalVelocitySCBValue->setObjectName("labelOrbitalVelocitySCBValue");

        gridLayout_9->addWidget(labelOrbitalVelocitySCBValue, 6, 1, 1, 1);


        gridLayout_10->addLayout(gridLayout_9, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_10->addItem(verticalSpacer, 1, 0, 1, 1);

        tabWidgetPC->addTab(tabData, QString());
        tabDistanceGraph = new QWidget();
        tabDistanceGraph->setObjectName("tabDistanceGraph");
        gridLayout_11 = new QGridLayout(tabDistanceGraph);
        gridLayout_11->setObjectName("gridLayout_11");
        gridLayout_11->setContentsMargins(0, 0, 0, 0);
        pcChartView = new QChartView(tabDistanceGraph);
        pcChartView->setObjectName("pcChartView");

        gridLayout_11->addWidget(pcChartView, 1, 0, 1, 1);

        lunarElongationGraphHorizontalLayout = new QHBoxLayout();
        lunarElongationGraphHorizontalLayout->setObjectName("lunarElongationGraphHorizontalLayout");
        horizontalSpacer_15 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        lunarElongationGraphHorizontalLayout->addItem(horizontalSpacer_15);

        exportPCPushButton = new QPushButton(tabDistanceGraph);
        exportPCPushButton->setObjectName("exportPCPushButton");

        lunarElongationGraphHorizontalLayout->addWidget(exportPCPushButton);


        gridLayout_11->addLayout(lunarElongationGraphHorizontalLayout, 3, 0, 1, 1);

        tabWidgetPC->addTab(tabDistanceGraph, QString());

        gridLayout_8->addWidget(tabWidgetPC, 1, 0, 1, 1);

        stackedWidget->addWidget(stackedWidgetPage7);
        stackedWidgetPage8 = new QWidget();
        stackedWidgetPage8->setObjectName("stackedWidgetPage8");
        gridLayout_18 = new QGridLayout(stackedWidgetPage8);
        gridLayout_18->setObjectName("gridLayout_18");
        tabWidgetEclipses = new QTabWidget(stackedWidgetPage8);
        tabWidgetEclipses->setObjectName("tabWidgetEclipses");
        tabWidgetEclipses->setTabPosition(QTabWidget::South);
        tabGolbalSolarEclipse = new QWidget();
        tabGolbalSolarEclipse->setObjectName("tabGolbalSolarEclipse");
        gridLayout_20 = new QGridLayout(tabGolbalSolarEclipse);
        gridLayout_20->setObjectName("gridLayout_20");
        horizontalLayout_40 = new QHBoxLayout();
        horizontalLayout_40->setObjectName("horizontalLayout_40");
        solareclipsesCleanupButton = new QPushButton(tabGolbalSolarEclipse);
        solareclipsesCleanupButton->setObjectName("solareclipsesCleanupButton");

        horizontalLayout_40->addWidget(solareclipsesCleanupButton);

        solareclipsesSaveButton = new QPushButton(tabGolbalSolarEclipse);
        solareclipsesSaveButton->setObjectName("solareclipsesSaveButton");

        horizontalLayout_40->addWidget(solareclipsesSaveButton);

        solareclipsescontactsSaveButton = new QPushButton(tabGolbalSolarEclipse);
        solareclipsescontactsSaveButton->setObjectName("solareclipsescontactsSaveButton");

        horizontalLayout_40->addWidget(solareclipsescontactsSaveButton);

        solareclipsesMapSaveButton = new QPushButton(tabGolbalSolarEclipse);
        solareclipsesMapSaveButton->setObjectName("solareclipsesMapSaveButton");

        horizontalLayout_40->addWidget(solareclipsesMapSaveButton);

        solareclipsesCalculateButton = new QPushButton(tabGolbalSolarEclipse);
        solareclipsesCalculateButton->setObjectName("solareclipsesCalculateButton");

        horizontalLayout_40->addWidget(solareclipsesCalculateButton);


        gridLayout_20->addLayout(horizontalLayout_40, 5, 0, 1, 1);

        gammaNoteSolarEclipseLabel = new QLabel(tabGolbalSolarEclipse);
        gammaNoteSolarEclipseLabel->setObjectName("gammaNoteSolarEclipseLabel");
        gammaNoteSolarEclipseLabel->setWordWrap(true);

        gridLayout_20->addWidget(gammaNoteSolarEclipseLabel, 4, 0, 1, 1);

        solareclipseTreeWidget = new QTreeWidget(tabGolbalSolarEclipse);
        solareclipseTreeWidget->setObjectName("solareclipseTreeWidget");
        solareclipseTreeWidget->setRootIsDecorated(false);
        solareclipseTreeWidget->setUniformRowHeights(true);
        solareclipseTreeWidget->setItemsExpandable(false);
        solareclipseTreeWidget->setSortingEnabled(true);
        solareclipseTreeWidget->setExpandsOnDoubleClick(false);
        solareclipseTreeWidget->setColumnCount(0);
        solareclipseTreeWidget->header()->setProperty("showSortIndicator", QVariant(true));

        gridLayout_20->addWidget(solareclipseTreeWidget, 2, 0, 1, 1);

        solareclipsecontactsTreeWidget = new QTreeWidget(tabGolbalSolarEclipse);
        solareclipsecontactsTreeWidget->setObjectName("solareclipsecontactsTreeWidget");
        solareclipsecontactsTreeWidget->setRootIsDecorated(false);
        solareclipsecontactsTreeWidget->setUniformRowHeights(true);
        solareclipsecontactsTreeWidget->setItemsExpandable(false);
        solareclipsecontactsTreeWidget->setSortingEnabled(false);
        solareclipsecontactsTreeWidget->setExpandsOnDoubleClick(false);
        solareclipsecontactsTreeWidget->setColumnCount(0);
        solareclipsecontactsTreeWidget->header()->setProperty("showSortIndicator", QVariant(true));

        gridLayout_20->addWidget(solareclipsecontactsTreeWidget, 3, 0, 1, 1, Qt::AlignBottom);

        tabWidgetEclipses->addTab(tabGolbalSolarEclipse, QString());
        tabSolarEclipseLocal = new QWidget();
        tabSolarEclipseLocal->setObjectName("tabSolarEclipseLocal");
        gridLayout_21 = new QGridLayout(tabSolarEclipseLocal);
        gridLayout_21->setObjectName("gridLayout_21");
        horizontalLayout_44 = new QHBoxLayout();
        horizontalLayout_44->setObjectName("horizontalLayout_44");
        solareclipseslocalCleanupButton = new QPushButton(tabSolarEclipseLocal);
        solareclipseslocalCleanupButton->setObjectName("solareclipseslocalCleanupButton");

        horizontalLayout_44->addWidget(solareclipseslocalCleanupButton);

        solareclipseslocalSaveButton = new QPushButton(tabSolarEclipseLocal);
        solareclipseslocalSaveButton->setObjectName("solareclipseslocalSaveButton");

        horizontalLayout_44->addWidget(solareclipseslocalSaveButton);

        solareclipseslocalMapSaveButton = new QPushButton(tabSolarEclipseLocal);
        solareclipseslocalMapSaveButton->setObjectName("solareclipseslocalMapSaveButton");

        horizontalLayout_44->addWidget(solareclipseslocalMapSaveButton);

        solareclipseslocalCalculateButton = new QPushButton(tabSolarEclipseLocal);
        solareclipseslocalCalculateButton->setObjectName("solareclipseslocalCalculateButton");

        horizontalLayout_44->addWidget(solareclipseslocalCalculateButton);


        gridLayout_21->addLayout(horizontalLayout_44, 3, 0, 1, 1);

        solareclipselocalTreeWidget = new QTreeWidget(tabSolarEclipseLocal);
        solareclipselocalTreeWidget->setObjectName("solareclipselocalTreeWidget");
        solareclipselocalTreeWidget->setRootIsDecorated(false);
        solareclipselocalTreeWidget->setUniformRowHeights(true);
        solareclipselocalTreeWidget->setItemsExpandable(false);
        solareclipselocalTreeWidget->setSortingEnabled(true);
        solareclipselocalTreeWidget->setExpandsOnDoubleClick(false);
        solareclipselocalTreeWidget->setColumnCount(0);
        solareclipselocalTreeWidget->header()->setProperty("showSortIndicator", QVariant(true));

        gridLayout_21->addWidget(solareclipselocalTreeWidget, 1, 0, 1, 1);

        UncertaintiesNoteLabel = new QLabel(tabSolarEclipseLocal);
        UncertaintiesNoteLabel->setObjectName("UncertaintiesNoteLabel");
        UncertaintiesNoteLabel->setWordWrap(true);

        gridLayout_21->addWidget(UncertaintiesNoteLabel, 2, 0, 1, 1);

        tabWidgetEclipses->addTab(tabSolarEclipseLocal, QString());
        tabLunarEclipse = new QWidget();
        tabLunarEclipse->setObjectName("tabLunarEclipse");
        gridLayout_19 = new QGridLayout(tabLunarEclipse);
        gridLayout_19->setObjectName("gridLayout_19");
        lunareclipseTreeWidget = new QTreeWidget(tabLunarEclipse);
        lunareclipseTreeWidget->setObjectName("lunareclipseTreeWidget");
        lunareclipseTreeWidget->setRootIsDecorated(false);
        lunareclipseTreeWidget->setUniformRowHeights(true);
        lunareclipseTreeWidget->setItemsExpandable(false);
        lunareclipseTreeWidget->setSortingEnabled(true);
        lunareclipseTreeWidget->setExpandsOnDoubleClick(false);
        lunareclipseTreeWidget->setColumnCount(0);
        lunareclipseTreeWidget->header()->setProperty("showSortIndicator", QVariant(true));

        gridLayout_19->addWidget(lunareclipseTreeWidget, 1, 0, 1, 1);

        gammaNoteLabel = new QLabel(tabLunarEclipse);
        gammaNoteLabel->setObjectName("gammaNoteLabel");
        gammaNoteLabel->setWordWrap(true);

        gridLayout_19->addWidget(gammaNoteLabel, 3, 0, 1, 1);

        horizontalLayout_39 = new QHBoxLayout();
        horizontalLayout_39->setObjectName("horizontalLayout_39");
        lunareclipsesCleanupButton = new QPushButton(tabLunarEclipse);
        lunareclipsesCleanupButton->setObjectName("lunareclipsesCleanupButton");

        horizontalLayout_39->addWidget(lunareclipsesCleanupButton);

        lunareclipsesSaveButton = new QPushButton(tabLunarEclipse);
        lunareclipsesSaveButton->setObjectName("lunareclipsesSaveButton");

        horizontalLayout_39->addWidget(lunareclipsesSaveButton);

        lunareclipsescontactsSaveButton = new QPushButton(tabLunarEclipse);
        lunareclipsescontactsSaveButton->setObjectName("lunareclipsescontactsSaveButton");

        horizontalLayout_39->addWidget(lunareclipsescontactsSaveButton);

        lunareclipsesCalculateButton = new QPushButton(tabLunarEclipse);
        lunareclipsesCalculateButton->setObjectName("lunareclipsesCalculateButton");

        horizontalLayout_39->addWidget(lunareclipsesCalculateButton);


        gridLayout_19->addLayout(horizontalLayout_39, 4, 0, 1, 1);

        lunareclipsecontactsTreeWidget = new QTreeWidget(tabLunarEclipse);
        lunareclipsecontactsTreeWidget->setObjectName("lunareclipsecontactsTreeWidget");
        lunareclipsecontactsTreeWidget->setRootIsDecorated(false);
        lunareclipsecontactsTreeWidget->setUniformRowHeights(true);
        lunareclipsecontactsTreeWidget->setItemsExpandable(false);
        lunareclipsecontactsTreeWidget->setSortingEnabled(false);
        lunareclipsecontactsTreeWidget->setExpandsOnDoubleClick(false);
        lunareclipsecontactsTreeWidget->setColumnCount(0);
        lunareclipsecontactsTreeWidget->header()->setProperty("showSortIndicator", QVariant(true));

        gridLayout_19->addWidget(lunareclipsecontactsTreeWidget, 2, 0, 1, 1, Qt::AlignBottom);

        tabWidgetEclipses->addTab(tabLunarEclipse, QString());
        tabTransit = new QWidget();
        tabTransit->setObjectName("tabTransit");
        gridLayout_24 = new QGridLayout(tabTransit);
        gridLayout_24->setObjectName("gridLayout_24");
        transitTreeWidget = new QTreeWidget(tabTransit);
        transitTreeWidget->setObjectName("transitTreeWidget");
        transitTreeWidget->setRootIsDecorated(false);
        transitTreeWidget->setUniformRowHeights(true);
        transitTreeWidget->setItemsExpandable(false);
        transitTreeWidget->setSortingEnabled(true);
        transitTreeWidget->setExpandsOnDoubleClick(false);
        transitTreeWidget->setColumnCount(0);
        transitTreeWidget->header()->setProperty("showSortIndicator", QVariant(true));

        gridLayout_24->addWidget(transitTreeWidget, 1, 0, 1, 1);

        transitNoteLabel = new QLabel(tabTransit);
        transitNoteLabel->setObjectName("transitNoteLabel");
        transitNoteLabel->setWordWrap(true);

        gridLayout_24->addWidget(transitNoteLabel, 2, 0, 1, 1);

        horizontalLayout_45 = new QHBoxLayout();
        horizontalLayout_45->setObjectName("horizontalLayout_45");
        transitsCleanupButton = new QPushButton(tabTransit);
        transitsCleanupButton->setObjectName("transitsCleanupButton");

        horizontalLayout_45->addWidget(transitsCleanupButton);

        transitsSaveButton = new QPushButton(tabTransit);
        transitsSaveButton->setObjectName("transitsSaveButton");

        horizontalLayout_45->addWidget(transitsSaveButton);

        transitsCalculateButton = new QPushButton(tabTransit);
        transitsCalculateButton->setObjectName("transitsCalculateButton");

        horizontalLayout_45->addWidget(transitsCalculateButton);


        gridLayout_24->addLayout(horizontalLayout_45, 3, 0, 1, 1);

        tabWidgetEclipses->addTab(tabTransit, QString());

        gridLayout_18->addWidget(tabWidgetEclipses, 1, 0, 1, 1);

        gridLayout_28 = new QGridLayout();
        gridLayout_28->setObjectName("gridLayout_28");
        gridLayout_28->setContentsMargins(10, -1, 10, -1);
        horizontalLayout_42 = new QHBoxLayout();
        horizontalLayout_42->setObjectName("horizontalLayout_42");
        eclipseYearsLabel = new QLabel(stackedWidgetPage8);
        eclipseYearsLabel->setObjectName("eclipseYearsLabel");

        horizontalLayout_42->addWidget(eclipseYearsLabel);

        eclipseYearsSpinBox = new QSpinBox(stackedWidgetPage8);
        eclipseYearsSpinBox->setObjectName("eclipseYearsSpinBox");
        eclipseYearsSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        eclipseYearsSpinBox->setMinimum(1);
        eclipseYearsSpinBox->setMaximum(500);
        eclipseYearsSpinBox->setValue(10);

        horizontalLayout_42->addWidget(eclipseYearsSpinBox);

        eclipseYearsFinalLabel = new QLabel(stackedWidgetPage8);
        eclipseYearsFinalLabel->setObjectName("eclipseYearsFinalLabel");

        horizontalLayout_42->addWidget(eclipseYearsFinalLabel);


        gridLayout_28->addLayout(horizontalLayout_42, 0, 1, 1, 1);

        horizontalLayout_41 = new QHBoxLayout();
        horizontalLayout_41->setObjectName("horizontalLayout_41");
        eclipseHeaderLabel = new QLabel(stackedWidgetPage8);
        eclipseHeaderLabel->setObjectName("eclipseHeaderLabel");
        sizePolicy.setHeightForWidth(eclipseHeaderLabel->sizePolicy().hasHeightForWidth());
        eclipseHeaderLabel->setSizePolicy(sizePolicy);
        eclipseHeaderLabel->setFont(font);
        eclipseHeaderLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        eclipseHeaderLabel->setWordWrap(true);

        horizontalLayout_41->addWidget(eclipseHeaderLabel);

        horizontalSpacer_14 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_41->addItem(horizontalSpacer_14);

        eclipseFromLabel = new QLabel(stackedWidgetPage8);
        eclipseFromLabel->setObjectName("eclipseFromLabel");

        horizontalLayout_41->addWidget(eclipseFromLabel);

        eclipseFromYearSpinBox = new QSpinBox(stackedWidgetPage8);
        eclipseFromYearSpinBox->setObjectName("eclipseFromYearSpinBox");
        eclipseFromYearSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        eclipseFromYearSpinBox->setMinimum(-13000);
        eclipseFromYearSpinBox->setMaximum(17000);

        horizontalLayout_41->addWidget(eclipseFromYearSpinBox);


        gridLayout_28->addLayout(horizontalLayout_41, 0, 0, 1, 1);

        eclipseFilterWidget = new QWidget(stackedWidgetPage8);
        eclipseFilterWidget->setObjectName("eclipseFilterWidget");
        eclipseFilterWidget->setMinimumSize(QSize(50, 0));
        horizontalLayout_19 = new QHBoxLayout(eclipseFilterWidget);
        horizontalLayout_19->setObjectName("horizontalLayout_19");
        horizontalLayout_19->setContentsMargins(0, 0, 0, 0);
        eclipseFilterSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_19->addItem(eclipseFilterSpacer);

        eclipseFilterPenumbral = new QCheckBox(eclipseFilterWidget);
        eclipseFilterPenumbral->setObjectName("eclipseFilterPenumbral");
        eclipseFilterPenumbral->setChecked(true);

        horizontalLayout_19->addWidget(eclipseFilterPenumbral);

        eclipseFilterHybrid = new QCheckBox(eclipseFilterWidget);
        eclipseFilterHybrid->setObjectName("eclipseFilterHybrid");
        eclipseFilterHybrid->setChecked(true);

        horizontalLayout_19->addWidget(eclipseFilterHybrid);

        eclipseFilterAnnular = new QCheckBox(eclipseFilterWidget);
        eclipseFilterAnnular->setObjectName("eclipseFilterAnnular");
        eclipseFilterAnnular->setChecked(true);

        horizontalLayout_19->addWidget(eclipseFilterAnnular);

        eclipseFilterPartial = new QCheckBox(eclipseFilterWidget);
        eclipseFilterPartial->setObjectName("eclipseFilterPartial");
        eclipseFilterPartial->setChecked(true);

        horizontalLayout_19->addWidget(eclipseFilterPartial);

        eclipseFilterTotal = new QCheckBox(eclipseFilterWidget);
        eclipseFilterTotal->setObjectName("eclipseFilterTotal");
        eclipseFilterTotal->setChecked(true);

        horizontalLayout_19->addWidget(eclipseFilterTotal);


        gridLayout_28->addWidget(eclipseFilterWidget, 1, 0, 1, 2);


        gridLayout_18->addLayout(gridLayout_28, 0, 0, 1, 1);

        stackedWidget->addWidget(stackedWidgetPage8);
        stackedWidgetPage9 = new QWidget();
        stackedWidgetPage9->setObjectName("stackedWidgetPage9");
        gridLayout_27 = new QGridLayout(stackedWidgetPage9);
        gridLayout_27->setObjectName("gridLayout_27");
        astroCalcAlmanac = new AstroCalcAlmanacWidget(stackedWidgetPage9);
        astroCalcAlmanac->setObjectName("astroCalcAlmanac");
        QSizePolicy sizePolicy8(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy8.setHorizontalStretch(0);
        sizePolicy8.setVerticalStretch(0);
        sizePolicy8.setHeightForWidth(astroCalcAlmanac->sizePolicy().hasHeightForWidth());
        astroCalcAlmanac->setSizePolicy(sizePolicy8);

        gridLayout_27->addWidget(astroCalcAlmanac, 0, 0, 1, 1);

        stackedWidget->addWidget(stackedWidgetPage9);

        gridLayout_6->addWidget(stackedWidget, 1, 0, 1, 1);


        verticalLayout->addWidget(viewContent);


        retranslateUi(astroCalcDialogForm);

        stackedWidget->setCurrentIndex(0);
        tabWidgetPositions->setCurrentIndex(0);
        celestialBodyComboBox->setCurrentIndex(-1);
        tabWidgetGraphs->setCurrentIndex(0);
        tabWidgetPC->setCurrentIndex(0);
        tabWidgetEclipses->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(astroCalcDialogForm);
    } // setupUi

    void retranslateUi(QWidget *astroCalcDialogForm)
    {
        titleBar->setTitle(QCoreApplication::translate("astroCalcDialogForm", "Astronomical calculations", nullptr));

        const bool __sortingEnabled = stackListWidget->isSortingEnabled();
        stackListWidget->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = stackListWidget->item(0);
        ___qlistwidgetitem->setText(QCoreApplication::translate("astroCalcDialogForm", "Positions", nullptr));
#if QT_CONFIG(tooltip)
        ___qlistwidgetitem->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Celestial bodies above horizon", nullptr));
#endif // QT_CONFIG(tooltip)
        QListWidgetItem *___qlistwidgetitem1 = stackListWidget->item(1);
        ___qlistwidgetitem1->setText(QCoreApplication::translate("astroCalcDialogForm", "Ephemeris", nullptr));
        QListWidgetItem *___qlistwidgetitem2 = stackListWidget->item(2);
        ___qlistwidgetitem2->setText(QCoreApplication::translate("astroCalcDialogForm", "RTS", "rise, transit, set"));
#if QT_CONFIG(tooltip)
        ___qlistwidgetitem2->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Risings, Transits, and Settings", nullptr));
#endif // QT_CONFIG(tooltip)
        QListWidgetItem *___qlistwidgetitem3 = stackListWidget->item(3);
        ___qlistwidgetitem3->setText(QCoreApplication::translate("astroCalcDialogForm", "Phenomena", nullptr));
        QListWidgetItem *___qlistwidgetitem4 = stackListWidget->item(4);
        ___qlistwidgetitem4->setText(QCoreApplication::translate("astroCalcDialogForm", "Graphs", nullptr));
        QListWidgetItem *___qlistwidgetitem5 = stackListWidget->item(5);
        ___qlistwidgetitem5->setText(QCoreApplication::translate("astroCalcDialogForm", "WUT", "What's Up Tonight"));
#if QT_CONFIG(tooltip)
        ___qlistwidgetitem5->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "What's Up Tonight", nullptr));
#endif // QT_CONFIG(tooltip)
        QListWidgetItem *___qlistwidgetitem6 = stackListWidget->item(6);
        ___qlistwidgetitem6->setText(QCoreApplication::translate("astroCalcDialogForm", "PC", "Planetary Calculator"));
#if QT_CONFIG(tooltip)
        ___qlistwidgetitem6->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Planetary Calculator", nullptr));
#endif // QT_CONFIG(tooltip)
        QListWidgetItem *___qlistwidgetitem7 = stackListWidget->item(7);
        ___qlistwidgetitem7->setText(QCoreApplication::translate("astroCalcDialogForm", "Eclipses", nullptr));
#if QT_CONFIG(tooltip)
        ___qlistwidgetitem7->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Eclipses and transits", nullptr));
#endif // QT_CONFIG(tooltip)
        QListWidgetItem *___qlistwidgetitem8 = stackListWidget->item(8);
        ___qlistwidgetitem8->setText(QCoreApplication::translate("astroCalcDialogForm", "Almanac", nullptr));
        stackListWidget->setSortingEnabled(__sortingEnabled);

#if QT_CONFIG(tooltip)
        stackListWidget->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        celestialMagnitudeLimitLabel->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Show objects brighter than magnitude", nullptr));
#endif // QT_CONFIG(tooltip)
        celestialMagnitudeLimitLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Up to mag.:", nullptr));
#if QT_CONFIG(tooltip)
        horizontalCoordinatesCheckBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Use horizontal coordinates", nullptr));
#endif // QT_CONFIG(tooltip)
        horizontalCoordinatesCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "hor. coord.", "horizontal coordinates"));
#if QT_CONFIG(tooltip)
        celestialPositionsTreeWidget->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "List of objects above horizon", nullptr));
#endif // QT_CONFIG(tooltip)
        celestialPositionsTimeLabel->setText(QString());
        celestialPositionsSaveButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export positions...", nullptr));
        celestialPositionsUpdateButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Update positions", nullptr));
        tabWidgetPositions->setTabText(tabWidgetPositions->indexOf(tabObjects), QCoreApplication::translate("astroCalcDialogForm", "Seen now", nullptr));
        hecPositionsHeaderLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Heliocentric ecliptic positions of the major planets", nullptr));
        hecPositionsSaveButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export positions...", nullptr));
        hecPositionsExportButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export graph...", nullptr));
        hecPositionsUpdateButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Update positions", nullptr));
        hecSelectedMinorPlanetsCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "Include selected minor planets", nullptr));
#if QT_CONFIG(tooltip)
        hecBrightCometsCheckBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Show comets brighter than magnitude", nullptr));
#endif // QT_CONFIG(tooltip)
        hecBrightCometsCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "Include bright comets up to mag.:", nullptr));
        tabWidgetPositions->setTabText(tabWidgetPositions->indexOf(tabSolarSystem), QCoreApplication::translate("astroCalcDialogForm", "Major planets", nullptr));
        ephemerisCleanupButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Cleanup ephemerides", nullptr));
        ephemerisSaveButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export ephemeris...", nullptr));
#if QT_CONFIG(tooltip)
        ephemerisPushButton->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Calculations require time, please be patient", nullptr));
#endif // QT_CONFIG(tooltip)
        ephemerisPushButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Calculate ephemeris", nullptr));
        celestialBodyName->setText(QCoreApplication::translate("astroCalcDialogForm", "Celestial body:", nullptr));
#if QT_CONFIG(tooltip)
        celestialBodyComboBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "First celestial body", nullptr));
#endif // QT_CONFIG(tooltip)
        celestialBodyComboBox->setCurrentText(QString());
        labelAnd->setText(QCoreApplication::translate("astroCalcDialogForm", "and", nullptr));
#if QT_CONFIG(tooltip)
        secondaryCelestialBodyComboBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Second celestial body", nullptr));
#endif // QT_CONFIG(tooltip)
        labelOr->setText(QCoreApplication::translate("astroCalcDialogForm", "or", nullptr));
#if QT_CONFIG(tooltip)
        allNakedEyePlanetsCheckBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Compute ephemeris for all planets visible to the unaided eye (works on Earth only)", nullptr));
#endif // QT_CONFIG(tooltip)
        allNakedEyePlanetsCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "all naked-eye planets", nullptr));
        label->setText(QCoreApplication::translate("astroCalcDialogForm", "Show:", nullptr));
#if QT_CONFIG(tooltip)
        ephemerisShowLineCheckBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Show connecting line between the ephemeris markers", nullptr));
#endif // QT_CONFIG(tooltip)
        ephemerisShowLineCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "line", "show line"));
#if QT_CONFIG(tooltip)
        ephemerisShowMarkersCheckBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Show markers of positions of the current celestial body on the sky", nullptr));
#endif // QT_CONFIG(tooltip)
        ephemerisShowMarkersCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "markers", nullptr));
#if QT_CONFIG(tooltip)
        ephemerisShowDatesCheckBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Show dates of positions of current celestial body near markers", nullptr));
#endif // QT_CONFIG(tooltip)
        ephemerisShowDatesCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "dates", nullptr));
#if QT_CONFIG(tooltip)
        ephemerisShowMagnitudesCheckBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Show magnitudes of current celestial body (may be affected by atmosphere setting!)", nullptr));
#endif // QT_CONFIG(tooltip)
        ephemerisShowMagnitudesCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "magnitudes", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonExtraEphemerisDialog->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Extra options for ephemeris visualization", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        ephemerisIgnoreDateTestCheckBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Allow results outside recommended time range of orbital elements", nullptr));
#endif // QT_CONFIG(tooltip)
        ephemerisIgnoreDateTestCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "boundless", "Ignore date test"));
#if QT_CONFIG(tooltip)
        ephemerisHorizontalCoordinatesCheckBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Use horizontal coordinates", nullptr));
#endif // QT_CONFIG(tooltip)
        ephemerisHorizontalCoordinatesCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "hor. coord.", "horizontal coordinates"));
#if QT_CONFIG(tooltip)
        genericMarkerColor->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Color of ephemeris marker for first celestial body", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        secondaryMarkerColor->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Color of ephemeris marker for second celestial body", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        selectedMarkerColor->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Color of selected ephemeris marker", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        mercuryMarkerColor->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Color of Mercury's ephemeris marker", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        venusMarkerColor->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Color of Venus' ephemeris marker", nullptr));
#endif // QT_CONFIG(tooltip)
        venusMarkerColor->setText(QString());
#if QT_CONFIG(tooltip)
        marsMarkerColor->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Color of Mars' ephemeris marker", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        jupiterMarkerColor->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Color of Jupiter's ephemeris marker", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        saturnMarkerColor->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Color of Saturn's ephemeris marker", nullptr));
#endif // QT_CONFIG(tooltip)
        dateFromLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "From:", nullptr));
#if QT_CONFIG(tooltip)
        dateFromMonthSpinBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Month", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        dateFromDaySpinBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Day", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        dateFromHourSpinBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Hours", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        dateFromMinuteSpinBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Minutes", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        pushButtonNow->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Now", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonNow->setText(QString());
        dateToLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "to the next", nullptr));
        ephemerisStepLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Time step:", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonCustomStepsDialog->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Custom time step for ephemeris visualization", nullptr));
#endif // QT_CONFIG(tooltip)
        ephemerisNotificationLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Note: Positions depend on your settings for topocentric correction, aberration, etc. Magnitudes are affected by current atmosphere settings. For almanac-like data, disable atmosphere and topocentric corrections!", nullptr));
        rtsCleanupButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Cleanup data", nullptr));
        rtsSaveButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export data...", nullptr));
        rtsCalculateButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Calculate", nullptr));
        rtsCelestialBodyLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Celestial object:", nullptr));
        rtsCelestialBodyNameLabel->setText(QString());
        rtsFromLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "From:", nullptr));
#if QT_CONFIG(tooltip)
        rtsFromMonthSpinBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Month", nullptr));
#endif // QT_CONFIG(tooltip)
        rtsToLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "to the next", nullptr));
#if QT_CONFIG(tooltip)
        rtsToMonthSpinBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Duration in months", nullptr));
#endif // QT_CONFIG(tooltip)
        rtsToMonthsLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "mths", "duration, short form"));
        rtsHeaderLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Table of approximate risings, transits, and settings for selected celestial object", nullptr));
        rtsNotificationLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Note: artificial satellites and unnamed stars are excluded from calculation", nullptr));
        betweenObjectsLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Between objects:", nullptr));
        andLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "and", nullptr));
#if QT_CONFIG(tooltip)
        selectObjectButton->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Re-select previously selected object", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        allowedSeparationLabel->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        allowedSeparationLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Maximum allowed separation:", nullptr));
        phenomenFromLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "From:", nullptr));
#if QT_CONFIG(tooltip)
        phenomenFromMonthSpinBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Month", nullptr));
#endif // QT_CONFIG(tooltip)
        phenomenToLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "to the next", nullptr));
#if QT_CONFIG(tooltip)
        phenomenToMonthSpinBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Duration in months", nullptr));
#endif // QT_CONFIG(tooltip)
        phenomenToMonthsLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "mths", "duration, short form"));
        phenomenaCleanupButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Cleanup of phenomena", nullptr));
        phenomenaSaveButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export phenomena...", nullptr));
#if QT_CONFIG(tooltip)
        phenomenaPushButton->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Calculations require time, please be patient", nullptr));
#endif // QT_CONFIG(tooltip)
        phenomenaPushButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Calculate phenomena", nullptr));
        label_5->setText(QCoreApplication::translate("astroCalcDialogForm", "Calculate also:", nullptr));
        phenomenaOppositionCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "oppositions", nullptr));
        phenomenaPerihelionAphelionCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "perihelion and aphelion", nullptr));
        phenomenaElongationQuadratureCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "elongations and quadratures", nullptr));
        sunAltitudeCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "Also the graph for the Sun", nullptr));
        moonAltitudeCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "Also the graph for the Moon", nullptr));
#if QT_CONFIG(tooltip)
        positiveAltitudeOnlyCheckBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Draw only the part of the graph where altitude is greater than the value given in the right box.", nullptr));
#endif // QT_CONFIG(tooltip)
        positiveAltitudeOnlyCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "Above altitude:", nullptr));
#if QT_CONFIG(tooltip)
        positiveAltitudeLimitSpinBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Altitude limit in degrees", nullptr));
#endif // QT_CONFIG(tooltip)
        exportAltVsTimePushButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export graph...", nullptr));
        tabWidgetGraphs->setTabText(tabWidgetGraphs->indexOf(tabAltVsTime), QCoreApplication::translate("astroCalcDialogForm", "Altitude vs. Time", nullptr));
        exportAziVsTimePushButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export graph...", nullptr));
        tabWidgetGraphs->setTabText(tabWidgetGraphs->indexOf(tabAziVsTime), QCoreApplication::translate("astroCalcDialogForm", "Azimuth vs. Time", nullptr));
#if QT_CONFIG(tooltip)
        monthlyElevationPositiveCheckBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Draw only the part of the graph where altitude is greater than the value given in the right box.", nullptr));
#endif // QT_CONFIG(tooltip)
        monthlyElevationPositiveCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "Above altitude:", nullptr));
#if QT_CONFIG(tooltip)
        monthlyElevationPositiveLimitSpinBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Altitude limit in degrees", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        monthlyElevationTime->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Local Time in hours", nullptr));
#endif // QT_CONFIG(tooltip)
        monthlyElevationTimeInfo->setText(QString());
        exportMonthlyElevationPushButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export graph...", nullptr));
        tabWidgetGraphs->setTabText(tabWidgetGraphs->indexOf(tabMonthlyElevation), QCoreApplication::translate("astroCalcDialogForm", "Monthly Elevation", nullptr));
#if QT_CONFIG(tooltip)
        graphsDurationLabel->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "How many months to display", nullptr));
#endif // QT_CONFIG(tooltip)
        graphsDurationLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Duration:", nullptr));
#if QT_CONFIG(tooltip)
        graphsDurationSpinBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "How many months to display", nullptr));
#endif // QT_CONFIG(tooltip)
        graphsMonthsLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "months", "duration"));
        graphsStepLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Step:", nullptr));
#if QT_CONFIG(tooltip)
        graphsHourStepsSpinBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Step width for computation. Caution! Short steps cause slow graphs.", nullptr));
#endif // QT_CONFIG(tooltip)
        graphsHourStepsSpinBox->setSuffix(QCoreApplication::translate("astroCalcDialogForm", "h", nullptr));
        graphsSecondLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Second graph:", nullptr));
        graphsFirstLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "First graph:", nullptr));
        graphsNoteLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Notes: This tool works on Earth only! Short steps and long duration may cause a long delay!", nullptr));
        drawGraphsPushButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Draw graphs", nullptr));
        exportGraphsPushButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export graphs...", nullptr));
        tabWidgetGraphs->setTabText(tabWidgetGraphs->indexOf(tabTwoGraphs), QCoreApplication::translate("astroCalcDialogForm", "Graphs", nullptr));
        lunarElongationLimitLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Angular distance limit:", nullptr));
        lunarElongationNote->setText(QCoreApplication::translate("astroCalcDialogForm", "Important note: this tool works on Earth only!", nullptr));
        exportLunarElongationPushButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export graph...", nullptr));
        tabWidgetGraphs->setTabText(tabWidgetGraphs->indexOf(tabLunarElongation), QCoreApplication::translate("astroCalcDialogForm", "Lunar Elongation", nullptr));
        label_3->setText(QCoreApplication::translate("astroCalcDialogForm", "Select a category:", nullptr));
        label_6->setText(QCoreApplication::translate("astroCalcDialogForm", "Above altitude:", nullptr));
#if QT_CONFIG(tooltip)
        wutAngularSizeLimitMinSpinBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Minimal angular size for visible celestial objects", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        wutAngularSizeLimitMaxSpinBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Maximum angular size for visible celestial objects", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        wutAngularSizeLimitCheckBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Set limits for angular size for visible celestial objects", nullptr));
#endif // QT_CONFIG(tooltip)
        wutAngularSizeLimitCheckBox->setText(QCoreApplication::translate("astroCalcDialogForm", "Limit angular size:", nullptr));
        label_4->setText(QCoreApplication::translate("astroCalcDialogForm", "Matching objects:", nullptr));
        wutTimeIntervalLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Show objects which are up:", nullptr));
#if QT_CONFIG(tooltip)
        label_2->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Show objects brighter than magnitude", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(QCoreApplication::translate("astroCalcDialogForm", "Up to mag.:", nullptr));
        wutMatchingObjectsLineEdit->setPlaceholderText(QCoreApplication::translate("astroCalcDialogForm", "Search in list...", nullptr));
        saveObjectsButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export list of objects...", nullptr));
        labelFCB->setText(QCoreApplication::translate("astroCalcDialogForm", "First celestial body:", nullptr));
        labelSCB->setText(QCoreApplication::translate("astroCalcDialogForm", "Second celestial body:", nullptr));
        labelSynodicPeriod->setText(QCoreApplication::translate("astroCalcDialogForm", "Synodic period:", nullptr));
        labelEquatorialRadiiRatioValue->setText(QString());
        labelOrbitalVelocityFCB->setText(QCoreApplication::translate("astroCalcDialogForm", "Orbital velocity of first celestial body:", nullptr));
        labelAngularDistance->setText(QCoreApplication::translate("astroCalcDialogForm", "Angular distance:", nullptr));
        labelMeanMotionSCB->setText(QCoreApplication::translate("astroCalcDialogForm", "Mean motion of second celestial body:", nullptr));
        labelMeanMotionFCB->setText(QCoreApplication::translate("astroCalcDialogForm", "Mean motion of first celestial body:", nullptr));
        labelOrbitalVelocitySCB->setText(QCoreApplication::translate("astroCalcDialogForm", "Orbital velocity of second celestial body:", nullptr));
        labelOrbitalPeriodsRatio->setText(QCoreApplication::translate("astroCalcDialogForm", "Orbital periods ratio:", nullptr));
        labelEquatorialRadiiRatioRatio->setText(QCoreApplication::translate("astroCalcDialogForm", "Equatorial diameters ratio:", nullptr));
        labelLinearDistance->setText(QCoreApplication::translate("astroCalcDialogForm", "Linear distance:", nullptr));
        tabWidgetPC->setTabText(tabWidgetPC->indexOf(tabData), QCoreApplication::translate("astroCalcDialogForm", "Data", nullptr));
        exportPCPushButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export graph...", nullptr));
        tabWidgetPC->setTabText(tabWidgetPC->indexOf(tabDistanceGraph), QCoreApplication::translate("astroCalcDialogForm", "Graphs", nullptr));
        solareclipsesCleanupButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Cleanup eclipses", nullptr));
        solareclipsesSaveButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export eclipses...", nullptr));
        solareclipsescontactsSaveButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export circumstances...", nullptr));
#if QT_CONFIG(tooltip)
        solareclipsesMapSaveButton->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Export a visibility map of the selected eclipse", nullptr));
#endif // QT_CONFIG(tooltip)
        solareclipsesMapSaveButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export map...", nullptr));
        solareclipsesCalculateButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Calculate eclipses", nullptr));
        gammaNoteSolarEclipseLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Notes: The quantity gamma is the minimum distance from the axis of lunar shadow cone to the center of Earth, in units of Earth\342\200\231s equatorial radius. This distance is positive or negative, depending on whether the axis of the shadow cone passes north or south of the Earth's center. Path of solar eclipses during thousands of years in the past and future are not reliable due to uncertainty in \316\224T which is caused by fluctuations in Earth's rotation.", nullptr));
        tabWidgetEclipses->setTabText(tabWidgetEclipses->indexOf(tabGolbalSolarEclipse), QCoreApplication::translate("astroCalcDialogForm", "All Solar Eclipses", nullptr));
        solareclipseslocalCleanupButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Cleanup eclipses", nullptr));
        solareclipseslocalSaveButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export eclipses...", nullptr));
#if QT_CONFIG(tooltip)
        solareclipseslocalMapSaveButton->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Export a visibility map of the selected eclipse", nullptr));
#endif // QT_CONFIG(tooltip)
        solareclipseslocalMapSaveButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export map...", nullptr));
        solareclipseslocalCalculateButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Calculate eclipses", nullptr));
        UncertaintiesNoteLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Note: Local circumstances for eclipses during thousands of years in the past and future are not reliable due to uncertainty in \316\224T which is caused by fluctuations in Earth's rotation.", nullptr));
        tabWidgetEclipses->setTabText(tabWidgetEclipses->indexOf(tabSolarEclipseLocal), QCoreApplication::translate("astroCalcDialogForm", "Local Solar Eclipses", nullptr));
        gammaNoteLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Notes: The quantity gamma is the minimum distance from the center of the Moon to the axis of Earth\342\200\231s umbral shadow cone, in units of Earth\342\200\231s equatorial radius. This distance is positive or negative, depending on whether the Moon passes north or south of the shadow cone axis. Local circumstances for eclipses during thousands of years in the past and future are not reliable due to uncertainty in \316\224T which is caused by fluctuations in Earth's rotation.", nullptr));
        lunareclipsesCleanupButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Cleanup eclipses", nullptr));
        lunareclipsesSaveButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export eclipses...", nullptr));
        lunareclipsescontactsSaveButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export circumstances...", nullptr));
        lunareclipsesCalculateButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Calculate eclipses", nullptr));
        tabWidgetEclipses->setTabText(tabWidgetEclipses->indexOf(tabLunarEclipse), QCoreApplication::translate("astroCalcDialogForm", "Lunar Eclipses", nullptr));
        transitNoteLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Notes: Time in parentheses means the contact is invisible at current location. Transit times during thousands of years in the past and future are not reliable due to uncertainty in \316\224T which is caused by fluctuations in Earth's rotation.", nullptr));
        transitsCleanupButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Cleanup transits", nullptr));
        transitsSaveButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Export transits...", nullptr));
        transitsCalculateButton->setText(QCoreApplication::translate("astroCalcDialogForm", "Calculate transits", nullptr));
        tabWidgetEclipses->setTabText(tabWidgetEclipses->indexOf(tabTransit), QCoreApplication::translate("astroCalcDialogForm", "Planetary Transits", nullptr));
        eclipseYearsLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "to the next", nullptr));
#if QT_CONFIG(tooltip)
        eclipseYearsSpinBox->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Duration in years", nullptr));
#endif // QT_CONFIG(tooltip)
        eclipseYearsFinalLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "yrs", "duration, short form"));
        eclipseHeaderLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "Table of solar eclipses", nullptr));
        eclipseFromLabel->setText(QCoreApplication::translate("astroCalcDialogForm", "From year", nullptr));
#if QT_CONFIG(tooltip)
        eclipseFilterPenumbral->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Include penumbral eclipses", nullptr));
#endif // QT_CONFIG(tooltip)
        eclipseFilterPenumbral->setText(QCoreApplication::translate("astroCalcDialogForm", "Penumbral", nullptr));
#if QT_CONFIG(tooltip)
        eclipseFilterHybrid->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Include hybrid eclipses", nullptr));
#endif // QT_CONFIG(tooltip)
        eclipseFilterHybrid->setText(QCoreApplication::translate("astroCalcDialogForm", "Hybrid", nullptr));
#if QT_CONFIG(tooltip)
        eclipseFilterAnnular->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Include annular eclipses", nullptr));
#endif // QT_CONFIG(tooltip)
        eclipseFilterAnnular->setText(QCoreApplication::translate("astroCalcDialogForm", "Annular", nullptr));
#if QT_CONFIG(tooltip)
        eclipseFilterPartial->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Include partial eclipses", nullptr));
#endif // QT_CONFIG(tooltip)
        eclipseFilterPartial->setText(QCoreApplication::translate("astroCalcDialogForm", "Partial", nullptr));
#if QT_CONFIG(tooltip)
        eclipseFilterTotal->setToolTip(QCoreApplication::translate("astroCalcDialogForm", "Include total eclipses", nullptr));
#endif // QT_CONFIG(tooltip)
        eclipseFilterTotal->setText(QCoreApplication::translate("astroCalcDialogForm", "Total", nullptr));
        (void)astroCalcDialogForm;
    } // retranslateUi

};

namespace Ui {
    class astroCalcDialogForm: public Ui_astroCalcDialogForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ASTROCALCDIALOG_H
